function numeroPorExtenso(n) {
    if (n === 0) return 'zero';

    const unidades = ['', 'um', 'dois', 'três', 'quatro', 'cinco', 'seis', 'sete', 'oito', 'nove'];
    const dezenas = ['', '', 'vinte', 'trinta', 'quarenta', 'cinquenta', 'sessenta', 'setenta', 'oitenta', 'noventa'];
    const especiais = ['dez', 'onze', 'doze', 'treze', 'quatorze', 'quinze', 'dezesseis', 'dezessete', 'dezoito', 'dezenove'];
    const centenas = ['', 'cem', 'duzentos', 'trezentos', 'quatrocentos', 'quinhentos', 'seiscentos', 'setecentos', 'oitocentos', 'novecentos'];

    function menosDeMil(num) {
        let str = '';

        if (num >= 100) {
            const c = Math.floor(num / 100);
            str += (c === 1 && num % 100 !== 0) ? 'cento' : centenas[c];
            num %= 100;
            if (num) str += ' e ';
        }
        
        if (num >= 20) {
            const d = Math.floor(num / 10);
            str += dezenas[d];
            num %= 10;
            if (num) str += ' e ';
        } else if (num >= 10) {
            str += especiais[num - 10];
            num = 0;
        }

        if (num > 0) str += unidades[num];
        return str;
    }

    function converteGrandeza(valor, singular, plural) {
        if (valor === 0) return '';
        if (valor === 1) return singular;
        return menosDeMil(valor) + ' ' + plural;
    }

    let result = '';
    const milhoes = Math.floor(n / 1_000_000);
    const milhares = Math.floor((n % 1_000_000) / 1_000);
    const restantes = n % 1_000;

    if (milhoes > 0) {
        result += converteGrandeza(milhoes, 'um milhão', 'milhões');
        if (milhares || restantes) result += ' e ';
    }
    
    if (milhares > 0) {
        result += (milhares === 1) ? 'mil' : menosDeMil(milhares) + ' mil';
        if (restantes) result += ' e ';
    }
    
    if (restantes > 0) result += menosDeMil(restantes);
   //return result.trim().toUpperCase();  // Transforma o texto em maiúsculas
//    return result.trim();
  return capitalizar(result.trim());  // Capitaliza apenas as iniciais de cada palavra
}
// Função auxiliar para capitalizar a inicial de cada palavra
function capitalizar(texto) {
    return texto.split(' ').map(palavra => palavra.charAt(0).toUpperCase() + palavra.slice(1)).join(' ');
}
// Exemplo de uso
console.log(numeroPorExtenso(1234567)); // "um milhão duzentos e trinta e quatro mil quinhentos e sessenta e sete"
console.log(numeroPorExtenso(1000000)); // "um milhão"
console.log(numeroPorExtenso(305020));  // "trezentos e cinco mil e vinte"
console.log(numeroPorExtenso(101));     // "cento e um"
