$(document).ready(function () {
    var tableHeight = $(window).height() * 0.65; // 70% da altura da janela
    carregaDocPorFinalizar();

    function carregaDocPorFinalizar() {
        $('#tabelaListaDocFinalizar').DataTable().clear().destroy();
        var dataTable = $('#tabelaListaDocFinalizar').DataTable({
            dom: '<"top"i>rt', // Remove a busca (s) e exibe apenas informações (i) e a tabela (t)
//            scrollY: tableHeight + "px", // Define a altura da rolagem vertical
//            scrollX: tableHeight + "px", // Ativa a rolagem horizontal
//            scrollCollapse: true, // Colapsa a tabela se não houver muitas linhas
            paging: false,
            ordering: false, // Desativa a ordenação
            info: false, // Remove a mensagem de informações
            language: {
                "decimal": ",",
                "thousands": ".",
                "emptyTable": "Nenhum dado disponível na tabela",
                "loadingRecords": "Carregando...",
                "processing": "Processando...",
                "zeroRecords": "Nenhum registro encontrado"
            },
            "ajax": {
                url: BASE_URL + "cFaturas/documentosPorFinalizar", // URL da requisição
                type: "post",
                "data": function (searchParams) {

                },
                "dataSrc": function (json) {
                    return json.data; // Onde json.data é o array de dados da tabela
                }
            },
            columns: [

                {data: "totalGeral"},
                {data: "totalLinha"},

                {
                    data: null,
                    render: function (data, type, row) {
                        return `
                    <a href="#" class="icon-action editar" data-id="${row.idVenda}" id="${row.idVenda}" title="Adicionar">
                        <i class="iconsminds-add-cart"></i>
                    </a>
                    <a href="#" class="icon-action eliminar" data-id="${row.idVenda}" id="${row.idVenda}" title="Eliminar">
                        <i class="iconsminds-delete-file"></i>
                    </a>
                `;
                    }
                },
                {data: "idProduto", visible: false}

            ],
//            
            createdRow: function (row, data, dataIndex) {
                // Adiciona a classe p-0 em todas as células <td> de cada linha criada
                $(row).find('td').addClass('p-1');
            }

        });
        // Listener para expandir/colapsar a linha ao clicar na linha inteira
        $('#tabelaListaDocFinalizar tbody').on('click', 'tr', function () {
            var tr = $(this);
            var row = dataTable.row(tr);

            if (row.child.isShown()) {
                // Fecha a sub-tabela se já estiver aberta
                row.child.hide();
                tr.removeClass('shown');
            } else {
                // Faz uma requisição AJAX para buscar dados da tabela aninhada
                var idVenda = row.data().idVenda;
                $.ajax({
                    url: BASE_URL + "cFaturas/detalhesDocumento", // URL para buscar dados da sub-tabela
                    type: "post",
                    dataType: 'json',
                    data: {idVenda: idVenda},
                    success: function (response) {
                        // Renderiza a tabela aninhada com os dados recebidos
                        console.log("Dados recebidos:", response);
                        // Verificando se a resposta é um array e tratando os dados
                        if (Array.isArray(response)) {
                            row.child(formatChildTable(response)).show();
                            tr.addClass('shown');
                        } else {
                            console.error('Resposta inválida ou ausente. Verifique os dados retornados.');
                            row.child('<p>Dados inválidos ou ausentes.</p>').show();
                            tr.addClass('shown');
                        }
                    },
                    error: function () {
                        alert("Erro ao carregar os detalhes.");
                    }
                });
            }
        });
    }
// Função para formatar a tabela aninhada
    function formatChildTable(response) {

        var table = '<table class="table table-borderless"><thead><tr><th>Produto</th><th>Quantidade</th><th>Preço</th><th>Subtotal</th></tr></thead><tbody>';
        response.forEach(function (item) {
            table += `<tr><td>${item.produto}</td><td>${item.quantidade}</td><td>${item.preco}</td><td>${item.total}</td></tr>`;
        });
        table += '</tbody></table>';
        return table;
    }

    // Evento de clique para o botão de editar
    $('#tabelaListaDocFinalizar tbody').on('click', '.editar', function () {
        // Acessa o idVenda diretamente do botão clicado
        var idVenda = $(this).data('id');
        localStorage.setItem('IdVenda', idVenda);
        var redirect = BASE_URL + 'cPainel/panel?pg=faturas';
        window.location = redirect;

    });

    // Evento de clique para o botão de eliminar
    $('#tabelaListaDocFinalizar tbody').on('click', '.eliminar', function () {
        var table = $('#tabelaListaIntensCarrinho').DataTable();
        var rowData = table.row($(this).closest('tr')).data();
//        var idProduto = rowData.idProduto;
        var idVenda = $(this).data('id');
        Swal.fire({
            icon: 'question', // Tipo do alerta: pergunta
            title: 'Atenção!',
            text: 'Deseja cancelar o documento em curso?',
            showCancelButton: true, // Mostra o botão de "Não"
            confirmButtonText: 'Sim', // Texto do botão de "Sim"
            cancelButtonText: 'Não', // Texto do botão de "Não"
            confirmButtonColor: '#3085d6', // Cor do botão de "Sim"
            cancelButtonColor: '#d33'      // Cor do botão de "Não"
        }).then((result) => {
            if (result.isConfirmed) {
                $.ajax({
                    type: 'post',
                    url: BASE_URL + "cFaturas/cancelarDocumento",
                    data: {idVenda: idVenda
                    },
                    dataType: 'json',
                    success: function (dados) {
                        if (dados === 'OK') {
                            $('#tabelaListaDocFinalizar').DataTable().ajax.reload();
                        }

                    }
                });
            } else if (result.dismiss === Swal.DismissReason.cancel) {
                // Ação para quando o usuário clica em "Não"
                console.log('Usuário clicou em Não');
            }
        });

        // Exemplo: confirmar a exclusão
    });
    // Abre a modal com o tipo de documento
    $(document).on('click', '.novoDoc', function () {
          localStorage.removeItem('IdVenda'); // 
        var redirect = BASE_URL + 'cPainel/panel?pg=faturas';
        window.location = redirect;
    });

});





