


function imprimirFaturaCinsolidadaPDF(empresa, produtos, entidade, dadosBanco, detalhesDoc) {
    const {jsPDF} = window.jspdf;

    const doc = new jsPDF({
        unit: 'mm',
        format: 'a4' // Alterar para o formato A4
    });

    let totalPages;
// Tamanho da página A4
    var pageWidth = doc.internal.pageSize.getWidth();

// Margens
    var marginTop = 15; // Distância do topo da página
    var marginBottom = 15; // Distância da parte inferior da página
    function addHeader() {
        doc.setFont("helvetica", "bold");
        doc.setFontSize(12);
        doc.text("Emitente:", 10, marginTop);
        // Dados da empresa
        doc.setFontSize(10);
        doc.setFont('helvetica', 'normal');
        doc.text(empresa.nomeEmpresa, 12, marginTop + 5);
        doc.text("NIF: " + empresa.nif, 12, marginTop + 10);
        doc.text("Endereço: " + empresa.endereco, 12, marginTop + 15);
        doc.text("Telefone: " + empresa.fone, 12, marginTop + 20);
        doc.text('Email:' + empresa.email, 12, marginTop + 25);
        doc.text(empresa.provincia + " - Angola", 12, marginTop + 30);
        doc.setFont("helvetica", "bold");
        doc.setFontSize(12);
        doc.text("Cliente:", 10, marginTop + 35);
        doc.setFontSize(10);
        doc.setFont('helvetica', 'normal');
        doc.text('Nome: ' + entidade.nome, 12, marginTop + 40);
        doc.text('NIF: ' + entidade.nif, 12, marginTop + 45);
        doc.text('Telemovel: ' + entidade.fone, 12, marginTop + 50);
        doc.text('Endereço: ' + entidade.localizacao, 12, marginTop + 55);

        // Título centralizado
        doc.setFontSize(14);
        doc.setTextColor(0, 0, 0);
        doc.text("Fatura Global", pageWidth / 2, marginTop + 60, {align: "center"});
        // Adiciona uma linha abaixo do texto
        let textWidth = doc.getTextWidth("Fatura Global"); // Obtém a largura do texto
        let textX = (pageWidth / 2) - (textWidth / 2); // Calcula a posição inicial da linha
        doc.setDrawColor(0, 0, 0); // Define a cor da linha (preta)
        doc.setLineWidth(0.5); // Define a espessura da linha
        doc.line(textX, marginTop + 62, textX + textWidth, marginTop + 62); // Linha contínua abaixo do texto

        // Período da consulta
        doc.setFontSize(12);
        // Adiciona linha separadora a cima da  data
        doc.setDrawColor(0, 0, 0); // Cor preta
        doc.setLineWidth(0.3); // Espessura da linha
        doc.line(10, marginTop + 65, pageWidth - 10, marginTop + 65); // Linha horizontal
        doc.setFont("helvetica", "bold");
        doc.text("Período de Apuração:", 10, marginTop + 71);
        // Converte as datas para o formato desejado
        var dataMin = new Date(detalhesDoc.dataminima).toLocaleDateString('pt-PT');
        var dataMax = new Date(detalhesDoc.datamaxima).toLocaleDateString('pt-PT');
        doc.text(dataMin, 65, marginTop + 71);
        doc.text("até", 110, marginTop + 71);
        doc.text(dataMax, 135, marginTop + 71);
//         Adiciona linha separadora abaixo do cabeçalho
        doc.setDrawColor(0, 0, 0); // Cor preta
        doc.setLineWidth(0.3); // Espessura da linha
        doc.line(10, marginTop + 72, pageWidth - 10, marginTop + 72); // Linha horizontal

    }
    addHeader();
    function addFooter(pageNumber) {
        var marginLeft = 10;   // Margem esquerda
        var marginRight = 10;  // Margem direita
        var pageWidth = doc.internal.pageSize.getWidth();
        var pageHeight = doc.internal.pageSize.getHeight();

        var startX = marginLeft;
        var endX = pageWidth - marginRight;

        var startYFooter = pageHeight - 10; // Ajuste para a posição do rodapé
        var text = 'Página ' + pageNumber;

        doc.setFontSize(8);

        // Calcula a largura do texto para alinhamento à direita
        var textWidth = doc.getTextWidth(text);
        var startXText = pageWidth - marginRight - textWidth;

        // Desenha a linha acima do número da página
        var lineY = startYFooter - 5; // Ajuste para a linha ficar logo acima
        doc.setDrawColor(0, 0, 0); // Cor preta
        doc.setLineWidth(0.3);
        doc.line(startX, lineY, endX, lineY);

        // Adiciona o número da página
        doc.text(text, startXText, startYFooter, {align: 'left'});
    }
    doc.setFontSize(10);
    doc.setFont('helvetica', 'normal');
// Define algumas variáveis para as margens e a posição vertical inicial
    const marginLeft = 10;
    const marginRight = 10;
    // Definir o ponto inicial para a tabela
    var startY = marginTop + 75; // Deixar espaço para o cabeçalho
    // Adicionar cabeçalho e rodapé na primeira página

    const grupoFaturas = produtos.reduce((groups, produto) => {
        // Se o grupo (fatura) ainda não foi criado, cria um objeto que armazena:
        // - Um array para os produtos
        // - A data da fatura (obtida do produto atual)
        if (!groups[produto.numeroFatuta]) {
            groups[produto.numeroFatuta] = {
                dataFatura: produto.dataEmissaoA4, // Armazena a data da fatura
                tipoDocumento: produto.tipoDocumento, // Armazena a data da fatura
                produtos: []
            };
        }
        groups[produto.numeroFatuta].produtos.push(produto);
        return groups;
    }, {});
    // Cria um array combinado com as linhas do corpo da tabela
// Para cada categoria, insere uma linha com o título da categoria e depois as linhas de produtos

    const totalColumns = 6; // Nossa tabela terá 6 colunas: Produto, Preço, Quantidade, Total
    let operacaoCount = 1;  // Contador para o número da operação
    for (let numeroFatuta in grupoFaturas) {
        // Para cada fatura, obtenha o grupo de produtos e a data
        let fatura = grupoFaturas[numeroFatuta];
        let produtosDaFatura = fatura.produtos; // Array com os produtos desta fatura



        const combinedRows = [];
        // Linha de título da fatura (cabeçalho da fatura)
        combinedRows.push([{
                content: "Operação nº: " + operacaoCount + " - " + fatura.tipoDocumento + " " + numeroFatuta + " (Data: " + fatura.dataFatura + ")",
                colSpan: totalColumns,
                styles: {halign: 'left', fontStyle: 'bolditalic', fontSize: 10, fillColor: [255, 255, 255]}
            }]);
        // Linha de cabeçalho das colunas para este grupo (inserida no body)
        combinedRows.push([
            {content: "Descrição", styles: {halign: 'left', fontStyle: 'bold', fontSize: 8}},
            {content: "Qtd", styles: {halign: 'center', fontStyle: 'bold', fontSize: 8}},
            {content: "Pr.Unitário", styles: {halign: 'center', fontStyle: 'bold', fontSize: 8}},
            {content: "Desconto%", styles: {halign: 'center', fontStyle: 'bold', fontSize: 8}},
            {content: "Taxa", styles: {halign: 'center', fontStyle: 'bold', fontSize: 8}},
            {content: "Valor", styles: {halign: 'right', fontStyle: 'bold', fontSize: 8}}
        ]);
        // Incrementa o contador para a próxima operação
        operacaoCount++;
        // Inicializa os acumuladores para os totais da categoria
        let sumSubTotal = 0;
        let sumTotalIva = 0;
        let sumTotalGeral = 0;
        // Para cada produto dessa fatura:
        produtosDaFatura.forEach(produto => {
            // Linha de detalhes do produto
            combinedRows.push([
                {content: produto.artigo, styles: {halign: 'left', fontSize: 8}},
                {content: produto.qtd, styles: {halign: 'center', fontSize: 8}},
                {content: moeda2(produto.custo), styles: {halign: 'center', fontSize: 8}},
                {content: moeda2(produto.percentagemDesconto), styles: {halign: 'center', fontSize: 8}},
                {content: produto.taxa, styles: {halign: 'center', fontSize: 8}},
                {content: moeda(produto.total), styles: {halign: 'right', fontSize: 8}}
            ]);
            sumSubTotal += parseFloat(produto.subTotal);
            sumTotalIva += parseFloat(produto.iva);
            sumTotalGeral += parseFloat(produto.total);

        });
        combinedRows.push([
            {
                content: "Total Ilíquido:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(sumSubTotal),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);
        combinedRows.push([
            {
                content: "Descontos Comerciais:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(0),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);
        combinedRows.push([
            {
                content: "Desconto Financeiro:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(0),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);
        combinedRows.push([
            {
                content: "Subtotal:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(sumSubTotal),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);
        combinedRows.push([
            {
                content: "IVA:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(sumTotalIva),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);
        combinedRows.push([
            {
                content: "Total documento:",
                colSpan: 4,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            },
            {content: moeda(sumTotalGeral),
                colSpan: 2,
                styles: {halign: 'right', fontStyle: 'bold', fontSize: 8},
                isTotalRow: true
            }
        ]);

// Gerar tabela com produtos
        doc.autoTable({
            startY: startY,
            margin: {top: 50, bottom: marginBottom, left: 10, right: 10},

            body: combinedRows,
            theme: 'plain', // Sem tema, personalizado
            styles: {
                fillColor: [255, 255, 255], // Remove a cor de fundo das linhas alternadas
                textColor: [0, 0, 0], // Cor do texto
                lineWidth: 0 // Remove todas as outras bordas das células
            },
            didParseCell: function (data) {
                data.cell.styles.minCellHeight = 5;  // Diminuir a altura mínima das células
            },
            headStyles: {
                fillColor: [230, 230, 230], // Cor de fundo do cabeçalho (cinza)
                textColor: 0, // Cor do texto (preto)
                fontStyle: 'bold', // Texto em negrito
                halign: 'center', // Alinhamento centralizado
                fontSize: 8, // Tamanho menor da fonte
                cellPadding: 2              // Menor espaçamento interno
            },
            columnStyles: {
                0: {cellWidth: 80, halign: 'left'}, // Produto
                1: {cellWidth: 20, halign: 'center'}, // Unidade
                3: {cellWidth: 20, halign: 'left'}, // Qtd
                5: {cellWidth: 20, halign: 'center'}, // Pr.Unitário
                5: {cellWidth: 22, halign: 'center'}, // Desconto
                6: {cellWidth: 15, halign: 'left'}, // Taxa
                7: {cellWidth: 26, halign: 'center'} // Valor
            },
            didDrawCell: function (data) {
                if (data.section === 'body') {
                    let cell = data.cell;
                    // Se a célula não for de uma linha de total, desenha a linha inferior
                    if (!(data.cell.raw && data.cell.raw.isTotalRow === true)) {
                        doc.setDrawColor(0, 0, 0);
                        doc.setLineWidth(0.0);
                        doc.line(cell.x, cell.y + cell.height, cell.x + cell.width, cell.y + cell.height);
                    }
                    // Opcionalmente, desenha a linha superior em todas as células:
                    doc.line(cell.x, cell.y + cell.height, cell.x + cell.width, cell.y + cell.height);
//                    doc.line(cell.x, cell.y, cell.x + cell.width, cell.y);
                }
            }

        });
        // Atualiza startY para a próxima fatura (pode ser doc.lastAutoTable.finalY + algum espaçamento)
        startY = doc.lastAutoTable.finalY + 10;
        // Verifica se é necessário adicionar nova página
        if (startY + 20 > doc.internal.pageSize.getHeight()) {
            doc.addPage();
            startY = marginTop + 25;
        }
    }











// Salva o PDF


    totalPages = doc.internal.getNumberOfPages();
    for (var i = 1; i <= totalPages; i++) {
        doc.setPage(i);
        addFooter(i);
    }

    var pdfOutput = doc.output('blob'); // Gera um blob do PDF
    var blobUrl = URL.createObjectURL(pdfOutput); // Cria uma URL para o blob

// Abre em uma nova aba
    window.open(blobUrl);


}


