function imprimeA4(empresa, detalhesDoc, entidade, dadosBanco, resumoImpostos, produtos) {
    const {jsPDF} = window.jspdf;

    const doc = new jsPDF({
        unit: 'mm',
        format: 'a4' // Alterar para o formato A4
    });


// Tamanho da página A4
    var pageWidth = doc.internal.pageSize.getWidth();
    var pageHeight = doc.internal.pageSize.getHeight();

// Margens
    var marginTop = 15; // Distância do topo da página
    var marginBottom = 100; // Distância da parte inferior da página

// Adicionar logotipo (substitua pelo caminho do seu logotipo)
    var logoWidth = 55;
    var logoHeight = 15;
    // Calcula a posição do logotipo
    var logoX = pageWidth - logoWidth - 10; // Posição à direita
    var logoY = 10; // Posição vertical do logotipo
    // Detecta automaticamente o formato da imagem com base no Base64 ou na extensão

// Detecta automaticamente o formato da imagem
    // Função para detectar o formato da imagem com base no caminho (imagePath)
    function getImageType(imagePath) {
        if (imagePath.startsWith('data:image/')) {
            // Se for uma string Base64, extrai o tipo da imagem
            const match = imagePath.match(/data:image\/(png|jpeg|jpg|webp|gif);base64,/);
            return match ? match[1].toUpperCase() : 'JPEG'; // Padrão para JPEG
        } else {
            // Para URLs ou caminhos locais, obtém a extensão do arquivo
            const extension = imagePath.split('.').pop().toLowerCase();
            return extension === 'jpg' ? 'JPEG' : extension.toUpperCase();
        }
    }

// Função para verificar se a imagem existe
    function checkImageExists(url, callback) {
        var img = new Image();
        img.onload = function () {
            callback(true); // A imagem existe
        };
        img.onerror = function () {
            callback(false); // A imagem não foi encontrada
        };
        img.src = url;
    }

// Função para converter uma imagem para Base64
    function getBase64ImageFromUrl(url, callback) {
        var img = new Image();
        img.crossOrigin = "Anonymous"; // Evita problemas de CORS para imagens externas
        img.onload = function () {
            var canvas = document.createElement("canvas");
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext("2d");
            ctx.drawImage(img, 0, 0);
            var dataURL = canvas.toDataURL("image/png"); // Converte para Base64
            callback(dataURL);
        };
        img.onerror = function () {
            console.error("Erro ao carregar a imagem para conversão Base64:", url);
            callback(null);
        };
        img.src = url;
    }

// Agora chamamos a função para adicionar ao PDF
    checkImageExists(imagePath, function (exists) {
        if (exists) {
            getBase64ImageFromUrl(imagePath, function (base64Image) {
                if (base64Image) {
                    var imageType = getImageType(imagePath); // Define o tipo da imagem corretamente
                    doc.addImage(base64Image, imageType, logoX, logoY, logoWidth, logoHeight);
                } else {
                    console.warn("A imagem foi encontrada, mas não pôde ser convertida para Base64.");
                }
            });
        } else {
            console.warn("A imagem não foi encontrada: " + imagePath);
        }
    });



// Função para adicionar o cabeçalho
    function addHeader() {
        // Dados da empresa
        doc.setFontSize(11);
        doc.setFont('helvetica', 'bold');
        doc.text(empresa.nomeEmpresa, 10, marginTop);
          doc.setFontSize(10);
        doc.setFont('helvetica', 'normal');
        doc.text("Endereço: " + empresa.endereco, 10, marginTop + 5);
        doc.text("NIF: " + empresa.nif, 10, marginTop + 10);
        doc.text("Telefone: " + empresa.fone, 10, marginTop + 15);
        doc.text('Email:' + empresa.email, 10, marginTop + 20);
        doc.text(empresa.provincia + " - Angola", 10, marginTop + 25);
        // Linha decorativa (azul)
        doc.setLineDash([1, 2], 0);  // Define o padrão da linha para criar pontos
        doc.line(10, marginTop + 27, pageWidth - 10, marginTop + 27); // Desenha a linha
        // Texto "Original" no canto superior direito
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
//        doc.text(detalhesDoc.via, pageWidth - 25, marginTop + 26); 
//        / Defina a posição de início a partir da largura total da página

        const marginRight = 10; // Margem direita
        const startX2 = pageWidth - marginRight; // Posição inicial para alinhamento à direita

// Adicione o texto alinhado à direita
        doc.text(detalhesDoc.via, startX2, marginTop + 26, {align: 'right'});
        // Texto da Fatura (direito, abaixo da linha azul)
        doc.setFont('helvetica', 'bold');
        doc.setFontSize(10);
//        doc.text(detalhesDoc.tipoDocumento + ' ' + detalhesDoc.numeroFatuta, pageWidth - 65, marginTop + 31); // Abaixo da linha azul
        doc.text(detalhesDoc.tipoDocumento + ' ' + detalhesDoc.numeroFatuta, startX2, marginTop + 31, {align: 'right'});

        // Informações do cliente e da fatura
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
        doc.text('Cliente', 10, marginTop + 31);
        // Linha pontilhada abaixo dos dados  
        doc.setFont('helvetica', 'normal');
        doc.setDrawColor(0, 0, 0);
        doc.setLineWidth(0.5);
        doc.setLineDash([1, 2], 0); // Linha pontilhada
        doc.line(10, marginTop + 34, pageWidth - 10, marginTop + 34); // Desenha linha pontilhada
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        doc.text('Nome:', 10, marginTop + 38);
        doc.text(entidade.nome, 25, marginTop + 38);

        doc.text('NIF:', 10, marginTop + 42);
        doc.text(entidade.nif, 25, marginTop + 42);

        doc.text('Telemovel:', 10, marginTop + 46);
        doc.text(entidade.fone, 25, marginTop + 46);

        doc.text('Endereço:', 10, marginTop + 50);
        doc.text(entidade.localizacao, 25, marginTop + 50);
        // Informação da fatura à direita
        doc.setFont('helvetica', 'bold');
        doc.text('Data de Emissão:', pageWidth - 90, marginTop + 38);
        doc.setFont('helvetica', 'normal');
         doc.text(detalhesDoc.dataEmissaoA4, startX2, marginTop + 38, {align: 'right'});
        if (detalhesDoc.idTipoDocumento === '1') {
            doc.setFont('helvetica', 'bold');
            doc.text('Data de Vencimento:', pageWidth - 90, marginTop + 42);
            doc.setFont('helvetica', 'normal');
            doc.text(detalhesDoc.dataVencimento, startX2, marginTop + 42, {align: 'right'});
            doc.setFont('helvetica', 'bold');
            doc.text('Atendente:', pageWidth - 90, marginTop + 46);
            doc.setFont('helvetica', 'normal');
            doc.text(detalhesDoc.unome, startX2, marginTop + 46, {align: 'right'});
            
        } else {
            doc.setFont('helvetica', 'bold');
            doc.text('Atendente:', pageWidth - 90, marginTop + 42);
            doc.setFont('helvetica', 'normal');
             doc.text(detalhesDoc.unome, startX2, marginTop + 42, {align: 'right'});
        }

    }
    // Função para adicionar o cabeçalho em outras paginas
    function addHeader2() {
        // Dados da empresa
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
        doc.text(empresa.nomeEmpresa, 10, marginTop);
        doc.setFont('helvetica', 'normal');
        doc.text("Endereço: " + empresa.endereco, 10, marginTop + 5);
        doc.text("NIF: " + empresa.nif, 10, marginTop + 10);
        doc.text("Telefone: " + empresa.fone, 10, marginTop + 15);
        doc.text('Email:' + empresa.email, 10, marginTop + 20);
        doc.text(empresa.provincia + " - Angola", 10, marginTop + 25);

        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
        doc.text("________________________________", pageWidth - 70, marginTop + 20);
        doc.text("Transporte:", pageWidth - 70, marginTop + 25);
        doc.text(moeda(totalPrPagina), pageWidth - 25, marginTop + 25);

    }
    const stringQRCode = "NOME:" + empresa.nomeEmpresa + "|" +
                     "NIF:" + empresa.nif + "|" +
                     "FATURA:" + detalhesDoc.tipoDocumento + ' ' + detalhesDoc.numeroFatuta + "|" +
                     "DATA:" + detalhesDoc.dataEmissaoA4 + "|" +
                     "TOTAL:" + moeda(detalhesDoc.totalGeral) + "|" +
                     "IVA:" + moeda(detalhesDoc.totalIva) + "|" +
                     "CHAVE:" + detalhesDoc.hashcontrol;
// Função para adicionar o rodapé com número da página
    function addFooter(pageNumber) {
        // Adicionar a tabela de resumo do documento no rodapé do lado esquerdo
        var startX = 10;  // Posição X para alinhar à esquerda


        var startYFooter = pageHeight - 100;  // Posição Y inicial para os itens no rodapé
        // Primeira linha do rodapé: texto explicativo
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        var qrWidth = 20;
        var qrHeight = 20;
        QRCode.toDataURL(stringQRCode, {
            errorCorrectionLevel: 'H',
            type: 'image/png',
            width: qrWidth, // Use o valor definido para a largura do QR Code
            margin: 1,
            color: {
                dark: "#000000",
                light: "#ffffff"
            }
        }, function (err, base64Image) {
            if (err) {
                console.error("Erro ao gerar o QR Code:", err);
                return;
            }

            // Se a imagem foi gerada, calcula a posição horizontal para alinhá-la à direita
            var margemDireita = 10; // Defina a margem da direita
            var startX3 = pageWidth - qrWidth - margemDireita;

            // Adiciona a imagem ao PDF
            doc.addImage(base64Image, 'PNG', startX3, startYFooter, qrWidth, qrHeight);
        });


        doc.setDrawColor(0, 0, 0);
        doc.setLineWidth(0.5);
        doc.setLineDash([2, 2], 0); // Linha pontilhada
//        doc.line(10, marginTop + 30, pageWidth - 10, marginTop + 30); // Desenha linha pontilhada
        doc.line(10, startYFooter + 20, pageWidth - 10, startYFooter + 20); // Desenha linha pontilhada
        // Gerar o QR code usando a biblioteca qr-code-generator



// Texto original
        const texto = "Os bens/Serviços prestados foram colocados à disposição do cliente na data: " + detalhesDoc.dataEntrega + " e local do documento";

// Define a largura máxima do texto antes de quebrar a linha
        const maxWidth = 120; // Ajuste para o espaço disponível no PDF

// Divide o texto em múltiplas linhas
        const linhas = doc.splitTextToSize(texto, maxWidth);

// Adiciona o texto ao PDF com as quebras de linha automáticas
        doc.text(linhas, startX, startYFooter + 15);

        doc.text("Quadro de resumo de impostos", startX, startYFooter + 24);
        doc.text(detalhesDoc.impostoRegime, startX, startYFooter + 28);
        var startY = pageHeight - 71;
        if (detalhesDoc.idRegime === '2' || detalhesDoc.idRegime === '3') {
            startY = pageHeight - 66;
        }

        // Tabela de impostos
        const resumoImpostosRows = resumoImpostos.map(resumo => [
                {content: resumo.incidencia, styles: {fontSize: 8, halign: 'left'}},
                {content: resumo.taxa, styles: {fontSize: 8, halign: 'center'}},
                {content: resumo.imposto, styles: {fontSize: 8, halign: 'center'}}

            ]);
        doc.autoTable({
            head: [['Incidência', 'Taxa%', 'Imposto', 'Motivo Isenção']],
            body: resumoImpostosRows,
            startY: startY,
            theme: 'plain',
            columnStyles: {
                0: {cellWidth: 18}, // Incidência
                1: {cellWidth: 15}, // Taxa
                2: {cellWidth: 18}, // Imposto
                3: {cellWidth: 30} // Motivo Isenção
            },
            margin: {left: 10},
            styles: {
                fontSize: 8,
                minCellHeight: 4, // Define a altura mínima das células
                lineHeight: 1.0    // Ajusta o espaçamento das linhas (valor menor reduz a altura)
            },
            headStyles: {
                minCellHeight: 5  // Altura mínima para o cabeçalho, ajustável
            }
        });

        doc.text("Cordenadas Bancária", startX, startYFooter + 48);
        doc.text("_________________________________________________", startX, startYFooter + 50);
        // Tabela dados Banco
        const bancosRows = dadosBanco.map(dados => [
                {content: dados.banco, styles: {fontSize: 8, halign: 'left'}},
                {content: dados.iban, styles: {fontSize: 8, halign: 'right'}}

            ]);
        doc.autoTable({
            body: bancosRows,
            startY: pageHeight - 49,
            theme: 'plain',
            columnStyles: {
                0: {cellWidth: 18}, // Incidência
                1: {cellWidth: 60} // Taxa

            },
            margin: {left: 10},
            styles: {
                fontSize: 8,
                minCellHeight: 4, // Define a altura mínima das células
                lineHeight: 1.0    // Ajusta o espaçamento das linhas (valor menor reduz a altura)
            },
            headStyles: {
                minCellHeight: 5  // Altura mínima para o cabeçalho, ajustável
            }
        });
        const marginRight2 = 10; // Margem direita
        const startX5 = pageWidth - marginRight2; // Posição inicial para alinhamento à direita
        doc.setFontSize(8);
        doc.setFont('helvetica', 'bold');
        doc.text(numeroPorExtenso(detalhesDoc.totalGeral), startX5, startYFooter + 70, {align: 'right'});
        doc.setLineDash([1, 2], 0);  // Define o padrão da linha para criar pontos
        doc.line(10, startYFooter + 75, pageWidth - 10, startYFooter + 75);   // Desenha a linha pontilhada como pontos  
        doc.setFontSize(12);
        doc.setFont('helvetica', 'bold');
        doc.text(detalhesDoc.totalGeralAOA + " AOA", startX5, startYFooter + 80, {align: 'right'});
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        doc.setLineDash([1, 2], 0);  // Define o padrão da linha para criar pontos
        doc.line(10, startYFooter + 83, pageWidth - 10, startYFooter + 83);   // Desenha a linha pontilhada como pontos  
        doc.setFontSize(9);
        doc.text(detalhesDoc.hashcontrol + "-Processado por programa validado nº 141/AGT/2019 - ©SGESOFT", startX, startYFooter + 86);
        // Dados bancários
        //  doc.text("Coordenadas Bancárias", 10, pageHeight - 15);
//        // Adicionar a tabela de resumo do documento no rodapé do lado esquerdo
//        var startX = 10;  // Posição X para alinhar à esquerda
//        var startYFooter = pageHeight - 20;  // Posição Y inicial para os itens no rodapé

        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        const marginRight = 10; // Margem direita
        const startX4 = pageWidth - marginRight; // Posição inicial para alinhamento à direita
        doc.text("Total Líquido:", startX + 120, startYFooter + 24);
        doc.text(moeda(detalhesDoc.totalIliquidi), startX4, startYFooter + 24, {align: 'right'});
        // doc.text(moeda(detalhesDoc.totalIliquidi), startX + 167, startYFooter + 24);  // Exemplo de valor

        doc.text("Descontos Comerciais:", startX + 120, startYFooter + 28);
        doc.text(moeda(detalhesDoc.descoComercial), startX4, startYFooter + 28, {align: 'right'});


        doc.text("Desconto Financeiro:", startX + 120, startYFooter + 32);
        doc.text(moeda(detalhesDoc.descoFinaceiro), startX4, startYFooter + 32, {align: 'right'});

        doc.text("Sub-Total:", startX + 120, startYFooter + 36);
        doc.text(moeda(detalhesDoc.subtotal), startX4, startYFooter + 36, {align: 'right'});

        doc.text("Iva:", startX + 120, startYFooter + 40);
        doc.text(moeda(detalhesDoc.totalIva), startX4, startYFooter + 40, {align: 'right'});

        doc.text("Total Documento(Kz):", startX + 120, startYFooter + 44);
        doc.text(moeda(detalhesDoc.totalGeral), startX4, startYFooter + 44, {align: 'right'});



        // Número da página centralizado
        doc.setFontSize(8);
        doc.text('Página ' + pageNumber, startX4, startYFooter + 86, {align: 'right'});
    }
    function addFooter2(pageNumber) {
        // Adicionar a tabela de resumo do documento no rodapé do lado esquerdo
        var startX = 10;  // Posição X para alinhar à esquerda


        var startYFooter = pageHeight - 45;  // Posição Y inicial para os itens no rodapé
        // Primeira linha do rodapé: texto explicativo
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');

        //   doc.addImage(qr, 'PNG', startX + 169, startYFooter, qrWidth, qrHeight);
        //  doc.addImage(qr, 'PNG', startX + 169, startYFooter, qrWidth, qrHeight);
        // Linha pontilhada abaixo dos dados
        doc.setDrawColor(0, 0, 0);
        doc.setLineWidth(0.5);
        doc.setLineDash([2, 2], 0); // Linha pontilhada
        doc.setFontSize(12);
        doc.setFont('helvetica', 'bold');
        doc.text("__________________________________", startX + 110, startYFooter + 20);
        doc.text("A Transportar:", startX + 110, startYFooter + 26);
        doc.text(moeda(totalPrPagina), startX + 167, startYFooter + 27);  // Exemplo de valor
        doc.line(10, startYFooter + 36, pageWidth - 10, startYFooter + 36); // Desenha linha pontilhada
        doc.setFont('helvetica', 'normal');
        doc.setFontSize(9);
        doc.text(detalhesDoc.hashcontrol + "-Processado por programa validado nº 141/AGT/2019 - ©SGESOFT", startX, startYFooter + 35);




        // Número da página centralizado
        doc.setFontSize(8);
        doc.text('Página ' + pageNumber, startX + 167, startYFooter + 35);
    }

// Número da página
    var pageNumber = 1;

    let totalPrPagina = 0; // Variável para somar os valores da coluna 'Valor' apenas na primeira página

// Exemplo de dados (tabela de produtos)

    const produtoRows = produtos.map(produto => [
            {content: produto.conta, styles: {fontSize: 8, halign: 'left'}},
            {content: produto.produto, styles: {fontSize: 8, halign: 'left'}},
            {content: produto.nunidade, styles: {fontSize: 8, halign: 'center'}},
            {content: produto.qtd, styles: {fontSize: 8, halign: 'center'}},
            {content: produto.custo, styles: {fontSize: 8, halign: 'center'}},
            {content: produto.percentagemDesconto, styles: {fontSize: 8, halign: 'center'}},
            {content: produto.iva, styles: {fontSize: 8, halign: 'center'}},
            {content: moeda(produto.total), styles: {fontSize: 8, halign: 'right'}}
        ]);
// Definir o ponto inicial para a tabela
    var startY = marginTop + 55; // Deixar espaço para o cabeçalho
    // Adicionar cabeçalho e rodapé na primeira página

    let totalPages;
// Gerar tabela com produtos
    doc.autoTable({
        startY: startY,
        margin: {top: 50, bottom: marginBottom, left: 10, right: 10},

//        head: [['Nº', 'Designação', 'Unidade', 'Qtd', 'Pr.Unitário', 'Desconto', 'Taxa', 'Valor']],
        head: [[
                {content: "Nº", styles: {halign: 'center'}},
                {content: "Designação", styles: {halign: 'left'}},
                {content: "Unidade", styles: {halign: 'center'}},
                {content: "Qtd", styles: {halign: 'center'}},

                {content: "Pr.Unitário", styles: {halign: 'center'}},
                {content: "Desconto%", styles: {halign: 'center'}},
                {content: "Taxa", styles: {halign: 'center'}},
                {content: "Valor", styles: {halign: 'right'}}
            ]
        ],
        body: produtoRows,
        theme: 'plain', // Sem tema, personalizado
        styles: {
            fillColor: [255, 255, 255], // Remove a cor de fundo das linhas alternadas
            textColor: [0, 0, 0], // Cor do texto
            lineWidth: 0 // Remove todas as outras bordas das células
        },
        didParseCell: function (data) {
            data.cell.styles.minCellHeight = 5;  // Diminuir a altura mínima das células
        },
        headStyles: {
            fillColor: [240, 240, 240], // Cabeçalho com cinza muito claro
            //textColor: [0, 0, 0], // Cor do texto do cabeçalho
            fontSize: 9 // Tamanho do texto no cabeçalho
        },
        columnStyles: {
            0: {cellWidth: 8, halign: 'left'}, // Nº
            1: {cellWidth: 64, halign: 'left'}, // Produto
            2: {cellWidth: 20, halign: 'center'}, // Unidade
            3: {cellWidth: 13, halign: 'center'}, // Qtd
            4: {cellWidth: 25, halign: 'center'}, // Pr.Unitário
            5: {cellWidth: 22, halign: 'center'}, // Desconto
            6: {cellWidth: 15, halign: 'center'}, // Taxa
            7: {cellWidth: 26, halign: 'center'} // Valor
        },
        didDrawCell: function (data) {
            if (data.section === 'body') {
                var cell = data.cell;
                var doc = data.doc;

                // Apenas a borda inferior
                doc.setDrawColor(0, 0, 0);  // Cor preta
                doc.setLineWidth(0.3);      // Espessura da linha inferior
                doc.line(
                        cell.x, cell.y + cell.height,
                        cell.x + cell.width, cell.y + cell.height
                        );
            }
        },
        didDrawPage: function (data) {

            const currentPage = data.pageNumber;
            marginBottom = (currentPage === 1) ? 20 : 100; // Define marginBottom: menor na primeira página
            if (currentPage === 1) {
                addHeader();
                totalPrPagina = produtos.reduce((acc, item) => acc + item.total, 0);
                console.log(totalPrPagina)

            } else {
                startY = marginTop + 80; // Posição inicial para páginas seguintes
            }
            doc.autoTable({
                startY: startY,
                margin: {top: marginTop, bottom: marginBottom, left: 10, right: 10}
                // Outras opções da tabela
            });
        }
    });
//   
    // Define o total de páginas após a primeira renderização
    totalPages = doc.internal.getNumberOfPages();

// Segunda renderização para aplicar rodapés ajustados
    if (totalPages > 1) {
        // Rodapé especial na primeira página com `marginBottom` ajustado
        doc.setPage(1);
        addFooter2(1, 20); // Rodapé especial com `marginBottom` menor

        // Rodapé comum para as demais páginas com `marginBottom` maior
        for (let i = 2; i <= totalPages; i++) {
            doc.setPage(i);
            addHeader2();
            addFooter(i, 100); // Rodapé comum com `marginBottom` maior
        }
    } else {
        // Caso haja apenas uma página, utiliza o rodapé comum
        doc.setPage(1);
        addFooter(1, 20); // Rodapé comum na única página
    }

// Checar se há mais páginas e adicionar cabeçalho em cada uma


// Salvar o PDF
//    doc.save('relatorio.pdf');
// Em vez de salvar, abra em uma nova aba
    var pdfOutput = doc.output('blob'); // Gera um blob do PDF
    var blobUrl = URL.createObjectURL(pdfOutput); // Cria uma URL para o blob

// Abre em uma nova aba
    window.open(blobUrl);


}


