
$(document).ready(function () {

    var currentPage = 1;
    var itemsPerPage = 5;  // Inicializa com 5 itens por página
    var totalPages = 0;
    var totalItems = 0;

    function fetchProducts() {
        var start = (currentPage - 1) * itemsPerPage;
        $.ajax({
            url: BASE_URL + "cItens/lista_itens",
            type: 'get',
            dataType: 'json',
            data: {
                start: start,
                limit: itemsPerPage,
                pesquisa: ''
            },
            success: function (response) {
                var products = response.products;
                totalItems = response.totalItems;  // Atualiza total de itens
                totalPages = Math.ceil(totalItems / itemsPerPage);

                renderProducts(products);
                updatePaginationControls();
                updateItemsInfo();
            },
            error: function () {
                console.log('Erro ao buscar os dados do backend.');
            }
        });
    }

    function renderProducts(products) {
        var productList = $('#product-list');
        productList.empty();

        products.forEach(function (product) {
            var cardHtml = `
                <div class="card d-flex flex-row mb-3">
                    <div class="d-flex flex-grow-1 min-width-zero">
                        <div class="card-body align-self-center d-flex flex-column flex-md-row justify-content-between min-width-zero align-items-md-center">
                            <a class="list-item-heading mb-0 truncate w-40 w-xs-100" href="#">
                                ${product.produto}
                            </a>
                            <p class="mb-0 text-muted text-small w-15 w-xs-100">${product.categoria}</p>
                            <p class="mb-0 text-muted text-small w-15 w-xs-100">${product.preco}</p>
                            <div class="w-15 w-xs-100">
                                <span class="badge badge-pill badge-primary">${product.idpr}</span>
                            </div>
                        </div>
                    </div>
            </div>`;
            productList.append(cardHtml);
        });
    }

    function updatePaginationControls() {

        if (currentPage === 1) {
            $('.first, .prev').parent().addClass('disabled');
        } else {
            $('.first, .prev').parent().removeClass('disabled');
        }

        if (currentPage === totalPages) {
            $('.next, .last').parent().addClass('disabled');
        } else {
            $('.next, .last').parent().removeClass('disabled');
        }

        $('.page-item').removeClass('active');
        $(`.page-item[data-page="${currentPage}"]`).addClass('active');

//         Eventos de clique nas páginas
        $('.page-item[data-page]').off('click').on('click', function (e) {
            e.preventDefault();
            var selectedPage = $(this).data('page');
            if (selectedPage !== currentPage) {
                currentPage = selectedPage;
                fetchProducts();  // Carregar os produtos da página selecionada
            }
        });

        // Evento de clique na página
        $('.page-item[data-page]').off('click').on('click', function () {
            currentPage = $(this).data('page');
            fetchProducts();
        });

        $('.first').off('click').on('click', function (e) {
            e.preventDefault();
            if (currentPage !== 1) {
                currentPage = 1;
                fetchProducts();
            }
        });

        $('.last').off('click').on('click', function (e) {
            e.preventDefault();
            if (currentPage !== totalPages) {
                currentPage = totalPages;
                fetchProducts();
            }
        });

        $('.prev').off('click').on('click', function (e) {
            e.preventDefault();
            if (currentPage > 1) {
                currentPage--;
                fetchProducts();
            }
        });

        $('.next').off('click').on('click', function (e) {
            e.preventDefault();
            if (currentPage < totalPages) {
                currentPage++;
                fetchProducts();
            }
        });
    }
    function updateItemsInfo() {
        var startItem = (currentPage - 1) * itemsPerPage + 1;
        var endItem = Math.min(currentPage * itemsPerPage, totalItems);
        $('.items-info').text(`Exibindo ${startItem}-${endItem} de ${totalItems} itens`);
    }





// Atualiza o número de itens por página ao selecionar no dropdown
    $('.dropdown-menu a').on('click', function (e) {
        e.preventDefault();
        itemsPerPage = parseInt($(this).text());  // Atualiza o valor de itemsPerPage
        currentPage = 1;  // Reinicia na primeira página
        fetchProducts();  // Recarrega os produtos
        $('.btn-outline-dark').text(itemsPerPage);  // Atualiza o botão com o novo valor
    });

// Carrega a primeira página
    fetchProducts();

});


