



function imprimeReciboPagamento(empresa, detalhesDoc, entidade, dadosRecibo) {
    const {jsPDF} = window.jspdf;

    const doc = new jsPDF({
        unit: 'mm',
        format: 'a4' // Alterar para o formato A4
    });


// Tamanho da página A4
    var pageWidth = doc.internal.pageSize.getWidth();
    var pageHeight = doc.internal.pageSize.getHeight();

// Margens
    var marginTop = 15; // Distância do topo da página
    var marginBottom = 20; // Distância da parte inferior da página

// Adicionar logotipo (substitua pelo caminho do seu logotipo)
    var logoWidth = 55;
    var logoHeight = 15;
    // Calcula a posição do logotipo
    var logoX = pageWidth - logoWidth - 10; // Posição à direita
    var logoY = 10; // Posição vertical do logotipo
    // Detecta automaticamente o formato da imagem com base no Base64 ou na extensão
    // Função para detectar o formato da imagem com base no caminho (imagePath)
    function getImageType(imagePath) {
        if (imagePath.startsWith('data:image/')) {
            // Se for uma string Base64, extrai o tipo da imagem
            const match = imagePath.match(/data:image\/(png|jpeg|jpg|webp|gif);base64,/);
            return match ? match[1].toUpperCase() : 'JPEG'; // Padrão para JPEG
        } else {
            // Para URLs ou caminhos locais, obtém a extensão do arquivo
            const extension = imagePath.split('.').pop().toLowerCase();
            return extension === 'jpg' ? 'JPEG' : extension.toUpperCase();
        }
    }

// Função para verificar se a imagem existe
    function checkImageExists(url, callback) {
        var img = new Image();
        img.onload = function () {
            callback(true); // A imagem existe
        };
        img.onerror = function () {
            callback(false); // A imagem não foi encontrada
        };
        img.src = url;
    }

// Função para converter uma imagem para Base64
    function getBase64ImageFromUrl(url, callback) {
        var img = new Image();
        img.crossOrigin = "Anonymous"; // Evita problemas de CORS para imagens externas
        img.onload = function () {
            var canvas = document.createElement("canvas");
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext("2d");
            ctx.drawImage(img, 0, 0);
            var dataURL = canvas.toDataURL("image/png"); // Converte para Base64
            callback(dataURL);
        };
        img.onerror = function () {
            console.error("Erro ao carregar a imagem para conversão Base64:", url);
            callback(null);
        };
        img.src = url;
    }

// Agora chamamos a função para adicionar ao PDF
    checkImageExists(imagePath, function (exists) {
        if (exists) {
            getBase64ImageFromUrl(imagePath, function (base64Image) {
                if (base64Image) {
                    var imageType = getImageType(imagePath); // Define o tipo da imagem corretamente
                    doc.addImage(base64Image, imageType, logoX, logoY, logoWidth, logoHeight);
                } else {
                    console.warn("A imagem foi encontrada, mas não pôde ser convertida para Base64.");
                }
            });
        } else {
            console.warn("A imagem não foi encontrada: " + imagePath);
        }
    });



// Função para adicionar o cabeçalho
    function addHeader() {
        // Dados da empresa
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
        doc.text(empresa.nomeEmpresa, 10, marginTop);
        doc.setFont('helvetica', 'normal');
        doc.text("Endereço: " + empresa.endereco, 10, marginTop + 5);
        doc.text("NIF: " + empresa.nif, 10, marginTop + 10);
        doc.text("Telefone: " + empresa.fone, 10, marginTop + 15);
        doc.text('Email:' + empresa.email, 10, marginTop + 20);
        doc.text(empresa.provincia + " - Angola", 10, marginTop + 25);
        // Linha decorativa (azul)
        doc.setLineDash([1, 2], 0);  // Define o padrão da linha para criar pontos
        doc.line(10, marginTop + 27, pageWidth - 10, marginTop + 27); // Desenha a linha
        // Texto "Original" no canto superior direito
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
//        doc.text(detalhesDoc.via, pageWidth - 25, marginTop + 26); 
//        / Defina a posição de início a partir da largura total da página

        const marginRight = 10; // Margem direita
        const startX2 = pageWidth - marginRight; // Posição inicial para alinhamento à direita
        // Texto da Fatura (direito, abaixo da linha azul)
        doc.setFont('helvetica', 'bold');
        doc.setFontSize(10);
//        doc.text(detalhesDoc.tipoDocumento + ' ' + detalhesDoc.numeroFatuta, pageWidth - 65, marginTop + 31); // Abaixo da linha azul
        doc.text(detalhesDoc.tipoDocumento + ' ' + detalhesDoc.numerodocumento, startX2, marginTop + 31, {align: 'right'});

        // Informações do cliente e da fatura
        doc.setFontSize(10);
        doc.setFont('helvetica', 'bold');
        doc.text('DADOS DA ENTIDADE', 10, marginTop + 31);
        // Linha pontilhada abaixo dos dados  
        doc.setFont('helvetica', 'normal');
        doc.setDrawColor(0, 0, 0);
        doc.setLineWidth(0.5);
        doc.setLineDash([1, 2], 0); // Linha pontilhada
        doc.line(10, marginTop + 34, pageWidth - 10, marginTop + 34); // Desenha linha pontilhada
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        doc.text('Nome:', 10, marginTop + 38);
        doc.text(entidade.nome, 25, marginTop + 38);

        doc.text('NIF:', 10, marginTop + 42);
        doc.text(entidade.nif, 25, marginTop + 42);

        doc.text('Telemovel:', 10, marginTop + 46);
        doc.text(entidade.fone, 25, marginTop + 46);

        doc.text('Endereço:', 10, marginTop + 50);
        doc.text(entidade.localizacao, 25, marginTop + 50);
        // Informação da fatura à direita
        doc.setFont('helvetica', 'bold');
        doc.text('Data de Emissão:', pageWidth - 90, marginTop + 38);
        doc.setFont('helvetica', 'normal');
        doc.text(detalhesDoc.dataEmissao, startX2, marginTop + 38, {align: 'right'});

        doc.setFont('helvetica', 'bold');

        doc.setFont('helvetica', 'bold');
        doc.text('Emitido por:', pageWidth - 90, marginTop + 46);
        doc.setFont('helvetica', 'normal');
        doc.text(detalhesDoc.usuario, startX2, marginTop + 46, {align: 'right'});


    }


// Função para adicionar o rodapé com número da página
    function addFooter(pageNumber) {
        // Adicionar a tabela de resumo do documento no rodapé do lado esquerdo
        var startX = 10;  // Posição X para alinhar à esquerda


        var startYFooter = pageHeight - 100;  // Posição Y inicial para os itens no rodapé
        // Primeira linha do rodapé: texto explicativo
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');



        doc.setFont('helvetica', 'normal');
        doc.setLineDash([1, 2], 0);  // Define o padrão da linha para criar pontos
        doc.line(10, startYFooter + 83, pageWidth - 10, startYFooter + 83);   // Desenha a linha pontilhada como pontos  
        doc.setFontSize(9);
        doc.text("Processado por programa validado nº 141/AGT/2019 - ©SGESOFT", startX, startYFooter + 88);
        doc.setFontSize(8);
        doc.setFont('helvetica', 'normal');
        const marginRight = 10; // Margem direita
        const startX4 = pageWidth - marginRight; // Posição inicial para alinhamento à direita

        doc.setFontSize(8);
        doc.text('Página ' + pageNumber, startX4, startYFooter + 88, {align: 'right'});
    }

    let totalPrPagina = 0; // Variável para somar os valores da coluna 'Valor' apenas na primeira página
    const reciboRows = dadosRecibo.map(recibo => [
            {content: recibo.docNumero, styles: {fontSize: 10, halign: 'left'}},
            {
                content: recibo.dataFatura
                        ? new Date(recibo.dataFatura).toLocaleDateString('pt-BR', {year: 'numeric', month: 'long', day: 'numeric'})
                        : "",
                styles: {fontSize: 10, halign: 'center'}
            },
            {content: moeda2(recibo.total), styles: {fontSize: 10, halign: 'center'}},
            {content: moeda2(recibo.totalIva), styles: {fontSize: 10, halign: 'center'}},
            {content: moeda(recibo.ivaRetido), styles: {fontSize: 10, halign: 'right'}}
        ]);



// Definir o ponto inicial para a tabela
    var startY = marginTop + 55; // Deixar espaço para o cabeçalho

    // Adicionar cabeçalho e rodapé na primeira página

    let totalPages;
// Gerar tabela com produtos
    doc.autoTable({
        startY: startY,
        margin: {top: 50, bottom: marginBottom, left: 10, right: 10},
        head: [[

                {content: "Designação", styles: {halign: 'left'}},
                {content: "Data da fatura", styles: {halign: 'center'}},
                {content: "Total da Fatura", styles: {halign: 'center'}},
                {content: "Total Impostos", styles: {halign: 'center'}},
                {content: "Reteção/Cativo", styles: {halign: 'right'}}
            ]
        ],
        body: reciboRows,
        theme: 'plain', // Sem tema, personalizado
        styles: {
            fillColor: [255, 255, 255], // Remove a cor de fundo das linhas alternadas
            textColor: [0, 0, 0], // Cor do texto
            lineWidth: 0 // Remove todas as outras bordas das células
        },
        didParseCell: function (data) {
            data.cell.styles.minCellHeight = 5;  // Diminuir a altura mínima das células
        },
        headStyles: {
            fillColor: [240, 240, 240], // Cabeçalho com cinza muito claro
            //textColor: [0, 0, 0], // Cor do texto do cabeçalho
            fontSize: 9 // Tamanho do texto no cabeçalho
        },
//       
        didDrawCell: function (data) {
            if (data.section === 'body') {
                var cell = data.cell;
                var doc = data.doc;

                // Apenas a borda inferior
                doc.setDrawColor(0, 0, 0);  // Cor preta
                doc.setLineWidth(0.3);      // Espessura da linha inferior
                doc.line(
                        cell.x, cell.y + cell.height,
                        cell.x + cell.width, cell.y + cell.height
                        );
            }
        },
        didDrawPage: function (data) {

            const currentPage = data.pageNumber;
            marginBottom = (currentPage === 1) ? 20 : 100; // Define marginBottom: menor na primeira página
            if (currentPage === 1) {
                addHeader();
                //     totalPrPagina = produtos.reduce((acc, item) => acc + item.total, 0);
                console.log(totalPrPagina)

            } else {
                startY = marginTop + 80; // Posição inicial para páginas seguintes
            }
            doc.autoTable({
                startY: startY,
                margin: {top: marginTop, bottom: marginBottom, left: 10, right: 10}
                // Outras opções da tabela
            });
        }
    });
    doc.setLineDash([]); // Reseta para borda contínua
    doc.rect(140, marginTop + 120, 60, 13, 'S');
    doc.setFont('helvetica', 'normal');
    doc.setFontSize(10);
    doc.text('Total pago', pageWidth - 69, marginTop + 125);
    doc.text('Pendente', pageWidth - 69, marginTop + 130);
    const marginRight = 10; // Margem direita
    const startX2 = pageWidth - marginRight; // Posição inicial para alinhamento à direita
     doc.setFont('helvetica', 'bold');
    doc.text(moeda(detalhesDoc.valorPgo), startX2, marginTop + 125, {align: 'right'});
     doc.text(moeda(detalhesDoc.pendente), startX2, marginTop + 130, {align: 'right'});
    // Agora, centralize o texto usando o ponto médio da página como coordenada X
    doc.setFont('helvetica', 'bold');
    doc.setFontSize(10);
    doc.text("Entregou", 25, marginTop + 140, );
    doc.text("Recebeu", 160, marginTop + 140, );
    doc.setFont('helvetica', 'normal');
    doc.setFontSize(9);
    doc.text("___________________", 15, marginTop + 146);
    doc.text("___________________", 150, marginTop + 146);
//   
    // Define o total de páginas após a primeira renderização
    totalPages = doc.internal.getNumberOfPages();

// Segunda renderização para aplicar rodapés ajustados
    if (totalPages > 1) {
        // Rodapé especial na primeira página com `marginBottom` ajustado
        doc.setPage(1);


    } else {
        // Caso haja apenas uma página, utiliza o rodapé comum
        doc.setPage(1);
        addFooter(1, 20); // Rodapé comum na única página
    }

// Checar se há mais páginas e adicionar cabeçalho em cada uma


// Salvar o PDF
//    doc.save('relatorio.pdf');
// Em vez de salvar, abra em uma nova aba
    var pdfOutput = doc.output('blob'); // Gera um blob do PDF
    var blobUrl = URL.createObjectURL(pdfOutput); // Cria uma URL para o blob

// Abre em uma nova aba
    window.open(blobUrl);


}


