


function imprimeTicketResumo(empresa, detalhesCaixa,produtos) {

    const {jsPDF} = window.jspdf;

    const doc = new jsPDF({
        unit: 'px',
//        format: [220.77, 1000] // 80mm de largura e altura dinâmica
        format: [160, 1000] // 80mm de largura e altura dinâmica
    });

// Definições de margens e posicionamento
    var marginLeft = 10;   // Margem esquerda
    var marginRight = 10;  // Margem direita
    var y = 12;            // Posição vertical inicial
//    var pageWidth = 220.77; // Definido como 80mm (220.77px) 
    var pageWidth = 160; // Definido como 80mm (220.77px) 
    var usableWidth = pageWidth - marginLeft * 2; // Largura utilizável para o texto 200

// Cabeçalho da empresa (Nome)
    doc.setFont("helvetica", "bold");
    doc.setFontSize(9);

// Dividir o nome da empresa em várias linhas se for necessário
    var text = doc.splitTextToSize(empresa.nomeEmpresa, usableWidth);

// Desenhar o nome da empresa com alinhamento à esquerda
    doc.text(text, marginLeft, y, {align: 'left'});
    y += 16; // Ajusta a posição vertical

// Definições para o restante do texto
    doc.setFont("helvetica", "normal");
    doc.setFontSize(9);

// Desenhar o endereço da empresa
    doc.text("Endereço: " + empresa.endereco, marginLeft, y, {align: 'left'});
    y += 10; // Ajusta a posição vertical

// Desenhar o NIF da empresa
    doc.text("NIF: " + empresa.nif, marginLeft, y, {align: 'left'});
    y += 10; // Ajusta a posição vertical

//    // Ajuste a fonte e tamanho para a tabela
    doc.setFontSize(10);
    doc.text("...................................................................", 10, y);
    y += 3;

    const tableData = [//detalhesCaixa
        [{content: "DADOS GERAIS", colSpan: 2, styles: {halign: 'center', fillColor: [230, 230, 230]}}],
        [{content: "TIPO", styles: {halign: 'center', fillColor: [230, 230, 230]}}, {content: "DETALHES", styles: {halign: 'center', fillColor: [230, 230, 230]}}],
        [{content: "Caixa", styles: {halign: 'left'}}, {content: detalhesCaixa.nome, styles: {halign: 'right'}}],
        [{content: "Estado", styles: {halign: 'left'}}, {content: detalhesCaixa.estado, styles: {halign: 'right'}}],
        [{content: "Dt.Abertura", styles: {halign: 'left'}}, {content: detalhesCaixa.aberto, styles: {halign: 'right'}}],
        [{content: "Dt.Fecho", styles: {halign: 'left'}}, {content: detalhesCaixa.encerrado, styles: {halign: 'right'}}],
        [{content: "Suprimentos", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.suprimentos), styles: {halign: 'right'}}],
        [{content: "Sangrias", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.sangria), styles: {halign: 'right'}}],
        [{content: "Vendas Cash", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.cash), styles: {halign: 'right'}}],
        [{content: "Vendas Tpa", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.tpa), styles: {halign: 'right'}}],
        [{content: "Total", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.total), styles: {halign: 'right'}}],
        [{content: "Informado", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.entreque), styles: {halign: 'right'}}],
        [{content: "Em falta", styles: {halign: 'left'}}, {content: moeda(detalhesCaixa.dif), styles: {halign: 'right'}}],
        [{content: "PRODUTOS VENDIDOS", colSpan: 2, styles: {halign: 'center', fillColor: [230, 230, 230]}}]
    ];

// Adicionar a tabela ao PDF usando autoTable
    doc.autoTable({
        body: tableData, // Dados da tabela
        startY: y, // Começo da tabela
        startX: marginLeft, // Definir a posição inicial horizontal para alinhar à esquerda
        theme: 'grid', // Estilo da tabela
        columnStyles: {
            0: {cellWidth: 55}, // Coluna da esquerda mais larga
            1: {cellWidth: 84}   // Coluna da direita

        },
        styles: {
            fontSize: 8, // Define o tamanho da fonte
            cellPadding: 1 // Diminui o espaçamento dentro das células para reduzir a altura da linha
        },
        margin: {left: marginLeft} // Define a margem para a tabela
    });
    y += 5;
//    // Dados dos produtos
//
    const produtoRows = produtos.map(produto => [
            {content: produto.produto, styles: {fontSize: 7, halign: 'left'}},
            {content: produto.qtd, styles: {fontSize: 7, halign: 'left'}},
            {content: moeda(produto.valor), styles: {fontSize: 7, halign: 'right'}}
        ]);
//
    // Cabeçalho e corpo da tabela
    doc.autoTable({
        startY: y + 120, // Começo da tabela
        startX: marginLeft, // Definir a posição inicial horizontal para alinhar à esquerda
        head: [
            [
                {content: "Produto", styles: {halign: 'left', fontSize: 8, fillColor: [230, 230, 230]}},
                {content: "Qtd", styles: {halign: 'center', fontSize: 8, fillColor: [230, 230, 230]}},
                {content: "Valor", styles: {halign: 'center', fontSize: 8, fillColor: [230, 230, 230]}}
            ]
        ],
         body: produtoRows,
        theme: 'grid', // Estilo da tabela

        columnStyles: {
            0: {cellWidth: 78}, // Largura da primeira coluna (Produto)
            1: {cellWidth: 20}, // Largura da segunda coluna (Quantidade)
            2: {cellWidth: 41}   // Largura da terceira coluna (IVA)

        },

        // Ajuste de padding e altura mínima das células
        styles: {
            fontSize: 7, // Define o tamanho da fonte
            cellPadding: 1, // Diminui o espaçamento dentro das células para reduzir a altura da linha
            lineColor: [211, 211, 211], // Cor da borda
            lineWidth: 0.01, // Define a espessura da linha para bordas mais finas
            textColor: [0, 0, 0]  // Cor do texto padrão
        },
       // tableWidth: 'wrap', // Ajusta a largura da tabela conforme o conteúdo das colunas
        margin: {left: marginLeft} // Define a margem para a tabela
    });
//
//    // Mover o Y para abaixo da tabela
//    let finalY = doc.lastAutoTable.finalY + 10;
//    doc.setFont("helvetica", "normal");
//    doc.setFontSize(10);
//    doc.text("...................................................................", 10, finalY);
//    finalY += 8;
//    doc.setFont("helvetica", "normal");
//    doc.setFontSize(8);
//    // Desenhar a primeira célula (texto alinhado à esquerda)
//    doc.text("Total ilíquido:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.totalIliquidi), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//    // Desenhar a  célula (texto alinhado à esquerda)
//    doc.text("Desc.Comercia:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.descoComercial), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//    // Desenhar a  célula (texto alinhado à esquerda)
//    doc.text("Desc. Financeiro:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.descoFinaceiro), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//    // Desenhar a  célula (texto alinhado à esquerda)
//    doc.text("Sub-Total:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.subtotal), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//    // Desenhar a  célula (texto alinhado à esquerda)
//    doc.text("IVA:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.totalIva), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//    // Desenhar a  célula (texto alinhado à esquerda)
//    doc.text("Total Documento:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//    doc.text(moeda(detalhesDoc.totalGeral), pageWidth - marginRight, finalY, {align: 'right'});
//    finalY += 8;
//
//    if (detalhesDoc.troco > 0) {
//        // Desenhar a  célula (texto alinhado à esquerda)
//        doc.text("Valor recebido:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//        doc.text(moeda(detalhesDoc.valorRecebido), pageWidth - marginRight, finalY, {align: 'right'});
//        finalY += 8;
//        // Desenhar a  célula (texto alinhado à esquerda)
//        doc.text("Troco:", marginLeft, finalY);
//// Desenhar a segunda célula (texto alinhado à direita)
//        doc.text(moeda(detalhesDoc.troco), pageWidth - marginRight, finalY, {align: 'right'});
//        finalY += 8;
//    }
//    doc.setFont("helvetica", "normal");
//    doc.setFontSize(10);
//    doc.text("...................................................................", 10, finalY);
//    finalY += 8;
//    if (detalhesDoc.idForma === '5') {
//        doc.setFontSize(8);
//        doc.text("Numerário: " + moeda(detalhesDoc.cash), 10, finalY);
//        finalY += 10;
//        doc.text("Multicaixa: " + moeda(detalhesDoc.tpa), 10, finalY);
//        finalY += 5;
//    } else {
//        doc.setFontSize(8);
//        doc.text("Forma Pagto: " + detalhesDoc.tipo, 10, finalY);
//        finalY += 5;
//    }
//    doc.setFontSize(10);
//    doc.text("...................................................................", 10, finalY);
//    finalY += 8;
//    doc.text("Impostos:" + detalhesDoc.impostoRegime, 10, finalY);
//    finalY += 5;
//
//    doc.setFont("helvetica", "normal");
//    doc.setFontSize(8);
//// Definições da tabela
//    var tableY = finalY + 5; // Deixar um espaço antes da tabela
//    var cellX = marginLeft; // Posição inicial horizontal da tabela
//    var lineHeight = 8; // Altura entre as linhas
//    // Definições da tabela
//    var cellWidths = [70, 30, 50]; // Largura de cada célula
//    if (detalhesDoc.idRegime === '2' || detalhesDoc.idRegime === '3') {
//        // Desenhar a primeira linha da tabela sem bordas
//        doc.text("Incidência", cellX + 2, tableY + 10); // Célula 1
//        cellX += cellWidths[0]; // Mover para a próxima célula
//        doc.text("Taxa%", cellX + 2, tableY + 10); // Célula 1
//        cellX += cellWidths[1]; // Mover para a próxima célula
//        doc.text("Imposto%", cellX + 2, tableY + 10); // Célula 1
//        cellX += cellWidths[2]; // Mover para a próxima célula
//    } else {
//        // Desenhar a primeira linha da tabela
//        doc.text("Incidência", cellX + 2, tableY); // Célula 1
//        cellX += cellWidths[0]; // Mover para a próxima célula
//        doc.text("Taxa%", cellX + 2, tableY); // Célula 2
//        cellX += cellWidths[1]; // Mover para a próxima célula
//        doc.text("Imposto%", cellX + 2, tableY); // Célula 3
//        cellX += cellWidths[2]; // Mover para a próxima célula
//
//        // Resetar `cellX` para a segunda linha
//        cellX = marginLeft;
//        tableY += lineHeight; // Mover para a segunda linha
//
//        // Segunda linha com valores
//        doc.text(moeda(detalhesDoc.subtotal), cellX + 2, tableY); // Valor de Incidência
//        cellX += cellWidths[0]; // Mover para a próxima célula
//        doc.text(14.00 + "%", cellX + 2, tableY); // Valor da Taxa%
//        cellX += cellWidths[1]; // Mover para a próxima célula
//        doc.text(moeda(detalhesDoc.totalIva), cellX + 2, tableY); // Valor do Imposto%
//        cellX += cellWidths[2]; // Mover para a próxima célula
//    }
//    finalY += 30;
//    // Dividir o nome da empresa em várias linhas se for necessário
//    doc.setFontSize(8);
//    var text = doc.splitTextToSize("Os bens foram colocados a disposição do cliente a datado documento", usableWidth);
//    // Desenhar o nome da empresa com alinhamento à esquerda
//    doc.text(text, marginLeft, finalY, {align: 'left'});
//    finalY += 10;
//    doc.setFontSize(10);
//    doc.text("...................................................................", 10, finalY);
//    finalY += 12;
//    doc.setFontSize(8);
//    var text = doc.splitTextToSize(detalhesDoc.hashcontrol + "-Processado por programa validado nº141/AGT/2019 - ©SGESOFT", usableWidth);
//    // Desenhar o texto com alinhamento centralizado
//    doc.text(text, pageWidth / 2, finalY, {align: 'center'});
//    finalY += 17;
//    doc.setFontSize(10);
//    var text = doc.splitTextToSize("Atendindo por: " + detalhesDoc.usuario, usableWidth);
//    // Desenhar o texto com alinhamento centralizado
//    doc.text(text, pageWidth / 2, finalY, {align: 'center'});
//    finalY += 12;
//    doc.setFontSize(8);
//    var text = doc.splitTextToSize("*****Obrigado pela preferência *****", usableWidth);
//    // Desenhar o texto com alinhamento centralizado
//    doc.text(text, pageWidth / 2, finalY, {align: 'center'});
//    finalY += 10;


    // Imprimir o PDF diretamente
    doc.autoPrint();

    const hiddFrame = document.createElement('iframe');
    hiddFrame.style.position = 'fixed';
// "visibility: hidden" would trigger safety rules in some browsers like safari，
// in which the iframe display in a pretty small size instead of hidden.
// here is some little hack ~
    hiddFrame.style.width = '1px';
    hiddFrame.style.height = '1px';
    hiddFrame.style.opacity = '0.01';
    const isSafari = /^((?!chrome|android).)*safari/i.test(window.navigator.userAgent);
    if (isSafari) {
        // fallback in safari
        hiddFrame.onload = () => {
            try {
                hiddFrame.contentWindow.document.execCommand('print', false, null);
            } catch (e) {
                hiddFrame.contentWindow.print();
            }
        };
    }
    hiddFrame.src = doc.output('bloburl');
    document.body.appendChild(hiddFrame);
}


