


function imprimeFaturaGlobal(empresa, ftItens, frItens, totais, datais) {
    const {jsPDF} = window.jspdf;

    const doc = new jsPDF({
        unit: 'mm',
        format: 'a4' // Alterar para o formato A4
    });

    let totalPages;
// Tamanho da página A4
    var pageWidth = doc.internal.pageSize.getWidth();
    var pageHeight = doc.internal.pageSize.getHeight();

// Margens
    var marginTop = 15; // Distância do topo da página
    var marginBottom = 100; // Distância da parte inferior da página
    function addHeader() {
        // Tamanho da página A4
        // Cabeçalho do documento
        doc.setFont("helvetica", "bold");
        doc.setFontSize(8);

        // Nome da empresa e data (data alinhada à direita)
        doc.text("Empresa: " + empresa.nomeEmpresa, 10, marginTop);
        doc.text("Data: " + new Date().toLocaleDateString(), pageWidth - 50, marginTop);

        // Título centralizado
        doc.setFontSize(14);
        doc.setTextColor(0, 0, 0);
        doc.text("Resumo de Vendas", pageWidth / 2, marginTop + 10, {align: "center"});
        // Adiciona uma linha abaixo do texto
        let textWidth = doc.getTextWidth("Resumo de Vendas"); // Obtém a largura do texto
        let textX = (pageWidth / 2) - (textWidth / 2); // Calcula a posição inicial da linha

        doc.setDrawColor(0, 0, 0); // Define a cor da linha (preta)
        doc.setLineWidth(0.5); // Define a espessura da linha
        doc.line(textX, marginTop + 12, textX + textWidth, marginTop + 12); // Linha contínua abaixo do texto

        // Período da consulta
        doc.setFontSize(12);
        doc.setFont("helvetica", "bold");
        doc.text("Equivalente desde:", 10, marginTop + 20);
        doc.text(datais.dataminima, 50, marginTop + 20);
        doc.text("até", 100, marginTop + 20);
        doc.text(datais.datamaxima, 130, marginTop + 20);
        // Adiciona linha separadora abaixo do cabeçalho
        doc.setDrawColor(0, 0, 0); // Cor preta
        doc.setLineWidth(0.3); // Espessura da linha
        doc.line(10, marginTop + 23, pageWidth - 10, marginTop + 23); // Linha horizontal

    }
    addHeader();
    function addFooter(pageNumber) {
        var marginLeft = 10;   // Margem esquerda
        var marginRight = 10;  // Margem direita
        var pageWidth = doc.internal.pageSize.getWidth();
        var pageHeight = doc.internal.pageSize.getHeight();

        var startX = marginLeft;
        var endX = pageWidth - marginRight;

        var startYFooter = pageHeight - 10; // Ajuste para a posição do rodapé
        var text = 'Página ' + pageNumber;

        doc.setFontSize(8);

        // Calcula a largura do texto para alinhamento à direita
        var textWidth = doc.getTextWidth(text);
        var startXText = pageWidth - marginRight - textWidth;

        // Desenha a linha acima do número da página
        var lineY = startYFooter - 5; // Ajuste para a linha ficar logo acima
        doc.setDrawColor(0, 0, 0); // Cor preta
        doc.setLineWidth(0.3);
        doc.line(startX, lineY, endX, lineY);

        // Adiciona o número da página
        doc.text(text, startXText, startYFooter, {align: 'left'});
    }


    // Dados para a tabela (exemplo)
    const ftRows = ftItens.map(itens => [
            {content: itens.numeroFatura, styles: {fontSize: 8, halign: 'left'}},
            {content: itens.dataVenda, styles: {fontSize: 8, halign: 'left'}},
            {content: itens.entidade, styles: {fontSize: 6, halign: 'center'}},
            {content: moeda2(itens.subtotalFt), styles: {fontSize: 8, halign: 'center'}},
            {content: moeda2(itens.descontosFt), styles: {fontSize: 8, halign: 'center'}},
            {content: moeda2(itens.totalFT), styles: {fontSize: 8, halign: 'center'}},
            {content: moeda2(itens.debitoFt), styles: {fontSize: 8, halign: 'center'}},
            {content: moeda2(itens.creditoFt), styles: {fontSize: 8, halign: 'right'}},
            {content: moeda2(itens.ivaFt), styles: {fontSize: 8, halign: 'right'}}
        ]);
    let totalSubtotalFt = 0, totalDescontosFt = 0, totalTotalFt = 0, totalDebitoFt = 0, totalCreditoFt = 0, totalIvaFt = 0;
    ftItens.forEach(item => {
        totalSubtotalFt += parseFloat(item.subtotalFt);
        totalDescontosFt += parseFloat(item.descontosFt);
        totalTotalFt += parseFloat(item.totalFT);
        totalDebitoFt += parseFloat(item.debitoFt);
        totalCreditoFt += parseFloat(item.creditoFt);
        totalIvaFt += parseFloat(item.ivaFt);
    });
    // Criar a linha de total (footer)
    const totalRowFt = [
        {content: "Total das faturas", colSpan: 3, styles: {fontSize: 8, halign: 'left', fontStyle: 'bold'}},
        {content: moeda2(totalSubtotalFt), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalDescontosFt), styles: {fontSize: 8, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalTotalFt), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalDebitoFt), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalCreditoFt), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}},
        {content: moeda2(totalIvaFt), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}}
    ];

    // Adiciona a linha de total ao final
    ftRows.push(totalRowFt);
    // Cria a tabela com autoTable, repetindo o cabeçalho em todas as páginas
    doc.autoTable({
        head: [

            // Linha de cabeçalho com os títulos das colunas
            ['Nº Fatura', 'Data', 'Cliente', 'Sub-total', 'Des.', 'Total', 'Débito', 'Crédito', 'Iva'],
            // Linha extra (sub-header) que aparecerá antes do cabeçalho normal
            [{
                    content: "FATURAS FT",
                    colSpan: 9, // Número total de colunas
                    styles: {halign: 'left', fontStyle: 'bold', fillColor: [255, 255, 255]}
                }]
                    // Segunda linha - Linha vazia para a linha pontilhada

        ],
        body: ftRows,
        startY: marginTop + 25,
        margin: {top: 50, bottom: marginBottom, left: 10, right: 10},
        showHead: 'everyPage',
        // Estilos personalizados:
        //  theme: 'grid', // Adiciona bordas em todas as células

        headStyles: {
            fillColor: [230, 230, 230], // Cor de fundo do cabeçalho (cinza)
            textColor: 0, // Cor do texto (preto)
            fontStyle: 'bold', // Texto em negrito
            halign: 'center', // Alinhamento centralizado
            fontSize: 8, // Tamanho menor da fonte
            cellPadding: 2              // Menor espaçamento interno
        },
        didDrawCell: function (data) {
            // Desenhar linha contínua abaixo do "FATURAS FT"
            if (data.row.index === 1 && data.section === 'head') {
                let {doc, cell} = data;
                doc.setDrawColor(0, 0, 0); // Cor preta
                doc.setLineWidth(0.5); // Espessura da linha
                doc.line(cell.x, cell.y + cell.height, cell.x + cell.width, cell.y + cell.height); // Linha contínua
            }
        },
        bodyStyles: {
            halign: 'left', // Alinhamento do corpo à esquerda
            cellPadding: 2, // Espaçamento interno das células
            fontSize: 8, // Menor espaçamento interno
            minCellHeight: 5           // Altura mínima das células reduzida// Tamanho menor da fonte para o corpo
        },
        columnStyles: {
            0: {cellWidth: 23}, // Largura automática para a coluna "Nº Fatura"
            1: {cellWidth: 18}, // Largura automática para "Data"
            2: {cellWidth: 28},
            3: {cellWidth: 18},
            4: {cellWidth: 14},
            5: {cellWidth: 27},
            6: {cellWidth: 20},
            7: {cellWidth: 15},
            8: {cellWidth: 27}
        }
    });
    // Obtém a posição onde terminou a primeira tabela
    let lastTableY = doc.lastAutoTable.finalY || marginTop + 25;
    const frRows = frItens.map(itens => [
            {content: itens.numeroFatura, styles: {fontSize: 7, halign: 'left'}},
            {content: itens.dataVenda, styles: {fontSize: 8, halign: 'left'}},
            {content: itens.entidade, styles: {fontSize: 6, halign: 'center'}},
            {content: moeda2(itens.subtotal), styles: {fontSize: 8, halign: 'center'}},
            {content: moeda2(itens.descontos), styles: {fontSize: 7, halign: 'center'}},
            {content: moeda2(itens.totalFr), styles: {fontSize: 7, halign: 'center'}},
            {content: moeda2(itens.debito), styles: {fontSize: 7, halign: 'center'}},
            {content: moeda2(itens.credito), styles: {fontSize: 8, halign: 'right'}},
            {content: moeda2(itens.iva), styles: {fontSize: 8, halign: 'right'}}
        ]);
    // Calcular os totais
    let totalSubtotal = 0, totalDescontos = 0, totalTotalFr = 0, totalDebito = 0, totalCredito = 0, totalIva = 0;
    frItens.forEach(item => {
        totalSubtotal += parseFloat(item.subtotal);
        totalDescontos += parseFloat(item.descontos);
        totalTotalFr += parseFloat(item.totalFr);
        totalDebito += parseFloat(item.debito);
        totalCredito += parseFloat(item.credito);
        totalIva += parseFloat(item.iva);
    });
    // Criar a linha de total (footer)
    const totalRow = [
        {content: "Total das faturas recibos", colSpan: 3, styles: {fontSize: 8, halign: 'left', fontStyle: 'bold'}},
        {content: moeda2(totalSubtotal), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalDescontos), styles: {fontSize: 8, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalTotalFr), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalDebito), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totalCredito), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}},
        {content: moeda2(totalIva), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}}
    ];
    // Criar a linha de total (footer)
    const totalGeral = [
        {content: "Total das FT e FR", colSpan: 3, styles: {fontSize: 8, halign: 'left', fontStyle: 'bold'}},
        {content: moeda2(totais.subTotalgeral), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totais.descontoGeral), styles: {fontSize: 8, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totais.totalGeral), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totais.debitoGeral), styles: {fontSize: 7, halign: 'center', fontStyle: 'bold'}},
        {content: moeda2(totais.creditoGeral), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}},
        {content: moeda2(totais.totalIva), styles: {fontSize: 8, halign: 'right', fontStyle: 'bold'}}
    ];

    // Adiciona a linha de total ao final
    frRows.push(totalRow);
    frRows.push(totalGeral);
    // Segunda tabela - começa logo após a primeira
    doc.autoTable({
        head: [

            // Linha de cabeçalho com os títulos das colunas
            ['Nº Fatura', 'Data', 'Cliente', 'Sub-total', 'Des.', 'Total', 'Débito', 'Crédito', 'Iva'],
            // Linha extra (sub-header) que aparecerá antes do cabeçalho normal
            [{
                    content: "FATURAS RECIBO",
                    colSpan: 9, // Número total de colunas
                    styles: {halign: 'left', fontStyle: 'bold', fillColor: [255, 255, 255]}
                }]
                    // Segunda linha - Linha vazia para a linha pontilhada
        ],
        body: frRows,
        startY: lastTableY + 2, // Inicia logo após a primeira tabela
        margin: {top: 50, bottom: 20, left: 10, right: 10},
        showHead: 'everyPage',
        headStyles: {
            fillColor: [230, 230, 230], // Cor de fundo do cabeçalho (cinza)
            textColor: 0, // Cor do texto (preto)
            fontStyle: 'bold', // Texto em negrito
            halign: 'center', // Alinhamento centralizado
            fontSize: 8, // Tamanho menor da fonte
            cellPadding: 2              // Menor espaçamento interno
        },
        didDrawCell: function (data) {
            const currentPage = data.pageNumber;

            // Ajusta margem superior na segunda página
            if (currentPage > 1 && data.row.index === 0 && data.section === 'head') {
                data.table.startY = 20;  // Define `startY` menor na segunda página
            }
            // Desenhar linha contínua abaixo do "FATURAS FT"
            if (data.row.index === 1 && data.section === 'head') {
                let {doc, cell} = data;
                doc.setDrawColor(0, 0, 0); // Cor preta
                doc.setLineWidth(0.5); // Espessura da linha
                doc.line(cell.x, cell.y + cell.height, cell.x + cell.width, cell.y + cell.height); // Linha contínua
            }
        },
        bodyStyles: {
            halign: 'left', // Alinhamento do corpo à esquerda
            cellPadding: 2, // Espaçamento interno das células
            fontSize: 8, // Menor espaçamento interno
            minCellHeight: 5           // Altura mínima das células reduzida// Tamanho menor da fonte para o corpo
        },
        columnStyles: {
            0: {cellWidth: 23}, // Largura automática para a coluna "Nº Fatura"
            1: {cellWidth: 18}, // Largura automática para "Data"
            2: {cellWidth: 28},
            3: {cellWidth: 18},
            4: {cellWidth: 14},
            5: {cellWidth: 27},
            6: {cellWidth: 20},
            7: {cellWidth: 15},
            8: {cellWidth: 27}

            // Ajuste outras colunas conforme necessário
        }
    });

    totalPages = doc.internal.getNumberOfPages();
    for (var i = 1; i <= totalPages; i++) {
        doc.setPage(i);
        addFooter(i);
    }

    var pdfOutput = doc.output('blob'); // Gera um blob do PDF
    var blobUrl = URL.createObjectURL(pdfOutput); // Cria uma URL para o blob

// Abre em uma nova aba
    window.open(blobUrl);


}


