$(document).ready(function () {

    $("#formFechoCaixa").validate({
        rules: {
            valor: {
                required: true, // Campo obrigatório
                number: true, // Aceita números decimais
                pattern: /^[0-9]*\.?[0-9]+$/ // Permite apenas números positivos
            }

        },
        messages: {
            valor: {
                required: "Por favor, insira um número.",
                number: "Por favor, insira um número válido.",
                pattern: "Por favor, insira apenas números positivos."
            }

        },
        errorElement: 'div',
        errorClass: 'invalid-feedback',
        highlight: function (element) {
            $(element).addClass('is-invalid'); // Adiciona classe de erro Bootstrap ao campo
        },
        unhighlight: function (element) {
            $(element).removeClass('is-invalid'); // Remove a classe de erro quando válido
        },
        errorPlacement: function (error, element) {
            error.insertAfter(element); // Insere a mensagem de erro logo após o campo
        },

        success: function (label, element) {
            // Remove o tooltip quando o campo for válido
            $(element).next('.error-tooltip').remove();
        },
        submitHandler: function (form) {
            // Chama a função submeteFormLogin quando o formulário for validado com sucesso
            submeteFormFeixoCaixa();

        }
    });
    function submeteFormFeixoCaixa() {
        var data = $("#formFechoCaixa").serialize(); // a function serialize serve para pegar todos os valores que foram colocados nos inputs do form
        var parametrosAdicionais = {
            idUsuario: idUsuario,
        };
// Concatene `data` com os parâmetros adicionais formatados
        data += "&" + $.param(parametrosAdicionais);

        $.ajax({
            // está é a função ajax, do jquery, ela será usada para fazer a requisição assícrona.
            url: BASE_URL + "cfluxocaixa/fecharCaixaGerente", // aqui vai a url da requisição
            data: data, // aqui vai os dados para o servidor, geralmente são os inputs do form
            method: "POST", // aqui vai o método da requisição, acho que você já sabe sobre o get e post !
            dataType: "json", // aqui será o tipo de resposta que vamos receber, será no formato json, um formato simples e mais usado.
            success: function (data) {
                // Admin/dashboard?page=dashboard
                if (data === 'OK') {
                    $("#exampleFecharCaixa").modal('hide');
                    docResCaixaPDF($("#idCaixaAberto").val());
                } else {
                    Swal.fire({
                        icon: 'info', // Tipo do alerta
                        title: 'Informação!',
                        text: data // Mensagem de erro
                    });
                }
            },
            error: function () {
                // Caso ocorra um erro na requisição
                Swal.fire({
                    icon: 'warning', // Tipo do alerta: aviso
                    title: 'Atenção!',
                    text: 'Ocorreu um erro na comunicação com o servidor.'
                });
            }
        });
    }
    carregaDadosCaixa();
    carregaSagriaSuprimentos();
    function carregaDadosCaixa() {
        $('#tabelaListaInformacaoCaixa').DataTable().clear().destroy();

        var dataTable = $('#tabelaListaInformacaoCaixa').DataTable({
            dom: '<"top"i>rt', // Remove a busca (s) e exibe apenas informações (i) e a tabela (t)
            scrollY: '200px', // Define a altura da rolagem vertical
            scrollX: true, // Ativa a rolagem horizontal
            scrollCollapse: true, // Colapsa a tabela se não houver muitas linhas
            paging: false,
            ordering: false, // Desativa a ordenação
            info: false, // Remove a mensagem de informações
            language: {
                "decimal": ",",
                "thousands": ".",
                "emptyTable": "Nenhum dado disponível",
                "loadingRecords": "Carregando...",
                "processing": "Processando...",
                "zeroRecords": "Nenhum registro encontrado"
            },
            "ajax": {
                url: BASE_URL + "cfluxocaixa/control_caixa_gerente", // URL da requisição
                type: "post",
                "data": function (searchParams) {
                    searchParams.idUsuario = idUsuario;
                },
                "dataSrc": function (json) {
                    // Aqui você pode capturar outros dados do retorno, como o total
                    // Retorna os dados para a tabela
                    return json.data; // Onde json.data é o array de dados da tabela
                }
            },

            columns: [
                {data: "dataCaixa"},
                {data: "saldoInicial"},
                {data: "sangrias"},
                {data: "vendaCash"},
                {data: "vendaTpa"},
                {data: "total"},
                {data: "entregue"},
                {data: "diferenca"},
                {
                    data: null,
                    render: function (data, type, row) {
                        return `
                    <a href="#" class="icon-action fechar" data-id="${row.idCaixaAberto}" title="Fechar Caixa">
                        <i class="iconsminds-cash-register-2"></i>
                    </a>
                    <a href="#" class="icon-action imprimir" data-id="${row.idCaixaAberto}" title="Imprimir resumo">
                        <i class="simple-icon-printer"></i>
                    </a>
                `;
                    }
                }

            ],
//            
            createdRow: function (row, data, dataIndex) {
                // Adiciona a classe p-0 em todas as células <td> de cada linha criada
                $(row).find('td').addClass('p-1');
            }

        });
    }

    function carregaSagriaSuprimentos() {
        $('#tabelaListaSangriaSuprimentos').DataTable().clear().destroy();

        var dataTable = $('#tabelaListaSangriaSuprimentos').DataTable({
            dom: '<"top"i>rt', // Remove a busca (s) e exibe apenas informações (i) e a tabela (t)
            scrollY: '200px', // Define a altura da rolagem vertical
            scrollX: true, // Ativa a rolagem horizontal
            scrollCollapse: true, // Colapsa a tabela se não houver muitas linhas
            paging: false,
            ordering: false, // Desativa a ordenação
            info: false, // Remove a mensagem de informações
            language: {
                "decimal": ",",
                "thousands": ".",
                "emptyTable": "Nenhum dado disponível",
                "loadingRecords": "Carregando...",
                "processing": "Processando...",
                "zeroRecords": "Nenhum registro encontrado"
            },
            "ajax": {
                url: BASE_URL + "cfluxocaixa/listarCaixaSangriaSuprimento", // URL da requisição
                type: "post",
                "data": function (searchParams) {
                    searchParams.idUsuario = idUsuario;
                },
                "dataSrc": function (json) {
                    // Aqui você pode capturar outros dados do retorno, como o total
                    // Retorna os dados para a tabela
                    return json.data; // Onde json.data é o array de dados da tabela
                }
            },

            columns: [
                {data: "dataCaixa"},
                {data: "tipo"},
                {data: "descricao"},
                {data: "usuario"},
                {data: "forma"},
                {data: "valor"}
            ],
//            
            createdRow: function (row, data, dataIndex) {
                // Adiciona a classe p-0 em todas as células <td> de cada linha criada
                $(row).find('td').addClass('p-1');
            }

        });
    }

    $(document).on('click', '.fechaModal', function () {
        $('.modal-backdrop').remove();
        $("#exampleModalLeft").modal('hide');
    });
    // Evento de clique para o botão de editar
    $('#tabelaListaInformacaoCaixa tbody').on('click', '.fechar', function () {
        var idCaixaAberto = $(this).data('id');
        $("#idCaixaAberto").val(idCaixaAberto);
        $("#exampleFecharCaixa").modal('show');
        carregaDadosCaixaModal(idCaixaAberto);

    });
    $('#tabelaListaInformacaoCaixa tbody').on('click', '.imprimir', function () {
        var idCaixaAberto = $(this).data('id');
       docResCaixaPDF(idCaixaAberto);

    });
    function carregaDadosCaixaModal(idCaixaAberto) {
        $.ajax({
            url: BASE_URL + "cfluxocaixa/dados_caixa", // aqui vai a url da requisição
            type: 'get',
            dataType: 'json',
            data: {
                idCaixaAberto: idCaixaAberto,
                idUsuario: idUsuario,
            },
            success: function (dados) {
                console.log(dados);
                $.each(dados, function (i, obj) {
                    $("#saldo").text(moeda(obj.saldoInicial));
                    $("#cash").text(moeda(obj.vendaCash));
                    $("#tpa").text(moeda(obj.vendaTpa));
                    $("#total").text(moeda(obj.total));
//                    $("#nome").val(obj.nome);
//                    $("#idCurso").val(obj.idCurso);
                });
            }
        });
    }

//    
    // Pega os dados da para o resumo de caixa(idFatura);
    function docResCaixaPDF(idCaixaAberto) {

        // Realizar a requisição AJAX para obter os dados dos produtos
        $.ajax({
            type: 'get',
            url: BASE_URL + "cDadosResCaixaPdF/docResCaixaPDF", // Substitua pela URL do seu endpoint
            dataType: 'json',
            data: {
                idCaixaAberto: idCaixaAberto,
                idUsuario: idUsuario
            },
            success: function (response) {
                var produtos = response.produtos;
                var detalhesCaixa = response.detalhesCaixa;
                var empresa = response.empresa;
                var itensCancelados = response.itensCancelados;
                imprimeTicketResumo(empresa,detalhesCaixa,produtos);
               
                

            },
            error: function (xhr, status, error) {
                console.error("Erro ao obter os produtos:", error);
                // Trate o erro como necessário
            }

        });
       
    }

});





