$(document).ready(function () {

    toastr.options = {
        "closeButton": true, // Adiciona um botão de fechar
        "debug": false, // Para propósitos de depuração
        "newestOnTop": true, // Exibe as notificações mais recentes no topo
        "progressBar": true, // Exibe uma barra de progresso para duração
        "positionClass": "toast-top-right", // Posição da notificação
        "preventDuplicates": true, // Evita duplicação de notificações
        "onclick": null, // Função de callback ao clicar na notificação
        "showDuration": "300", // Duração do efeito de exibição em ms
        "hideDuration": "1000", // Duração do efeito de ocultação em ms
        "timeOut": "5000", // Tempo que a notificação permanece visível
        "extendedTimeOut": "1000", // Tempo extra ao passar o mouse sobre a notificação
        "showEasing": "swing", // Tipo de efeito ao exibir
        "hideEasing": "linear", // Tipo de efeito ao ocultar
        "showMethod": "fadeIn", // Método de exibição
        "hideMethod": "fadeOut"           // Método de ocultação
    };

    carregaUtilizadores();
    var tableHeight = $(window).height() * 0.65; // 70% da altura da janela
    function carregaUtilizadores() {
        $('#tabelaUtilizadores').DataTable().clear().destroy();
        var dataTable = $('#tabelaUtilizadores').DataTable({
            scrollCollapse: true, // Colapsa a tabela se não houver muitas linhas
            colReorder: true,
            responsive: true,
            "processing": true,
            "serverSide": true,
            "searching": true,
            "ordering": false,
            "lengthChange": false,
            initComplete: function () {
                // Adicionar placeholder ao campo de pesquisa
                $('#tabelaEntidades_filter input').attr('placeholder', 'Procurar');
                // Adicionar classe personalizada para o ícone de lupa
                $('#tabelaEntidades_filter input').addClass('search-icon');
                $('#tabelaEntidades_filter input').css({
                    'padding-left': '30px',
                    'background-image': 'url("../../src/img/icon/search.png")',
                    'background-repeat': 'no-repeat',
                    'background-position': '5px center',
                    'background-size': '16px 16px',
                    'border': '1px solid #ced4da',
                    'border-radius': '20px',
                    'height': '35px'
                });
            },
            "language": {
                //   "lengthMenu": "Mostrando _MENU_ registros por página",
                "lengthMenu": "_MENU_",
                "zeroRecords": "Nada encontrado",
                "info": "Mostrando _START_ a _END_ de _TOTAL_ registos",
                //   info: "", // Define como uma string vazia
                "infoEmpty": "Nenhum registro disponível",
                "infoFiltered": "(filtrado de _MAX_ registros no total)",
                search: "", // Remove o texto padrão "Procurar"
                "processing": "Processando...",
                "paginate": {
                    "previous": "Anterior",
                    "next": "Próximo"
                },
                "oAria": {
                    "sSortAscending": ": Ativar para ordenar a coluna de forma ascendente",
                    "sSortDescending": ": Ativar para ordenar a coluna de forma descendente"
                }
            },
            "ajax": {
                url: BASE_URL + "CUtilizador/listarUtilizadores", // URL da requisição
                type: "post",
                "data": function (searchParams) {
                    searchParams.pesquisa = $("#search").val();
                },
                "dataSrc": function (json) {
                    return json.data; // Onde json.data é o array de dados da tabela
                }
            },
            columns: [
                {data: "unome"},
                {data: "nome"},
                {data: "utilizador"},
                {data: "data"},
//                {data: "email"},
//                {data: "localizacao"},
                {
                    data: null,
                    render: function (data, type, row) {
                        return `
                    <a href="#" class="icon-action editar"  data-id="${row.idUsuario}" title="Editar utilizador">
                        <i class="simple-icon-note"></i>
                    </a>
                        <a href="#" class="icon-action eliminar" data-id="${row.idUsuario}" title="Eliminar utilizador">
                        <i class="simple-icon-trash"></i>
                    </a>
                         <a href="#" class="icon-action trocaSenha" data-id="${row.idUsuario}" title="Trocar senha">
                        <i class="iconsminds-type-pass"></i>
                    </a>
                    <a href="#" class="icon-action permissoes" data-id="${row.idUsuario}" title="Permissão por utilizador">
                        <i class="iconsminds-key-lock"></i>
                    </a>
                `;
                    }
                }
            ]

        });
    }

    // Função para calcular a força da senha
    function verificarForcaSenha(senha) {
        let forca = 0;

        // Regras para pontuação
        if (senha.length >= 6)
            forca += 20; // Comprimento
        if (/[A-Z]/.test(senha))
            forca += 20; // Letras maiúsculas
        if (/[a-z]/.test(senha))
            forca += 20; // Letras minúsculas
        if (/\d/.test(senha))
            forca += 20; // Números
        if (/[@$!%*?&]/.test(senha))
            forca += 20; // Caracteres especiais

        return forca / 100; // Retorna um valor entre 0 e 1
    }
    $(document).on('click', '.novoUtilizador', function () {

//        $("#exampleEntidades").modal('show');
        $("#modalUtilizadores").modal({
            backdrop: 'static', // Impede fechar ao clicar fora
            keyboard: false     // Impede fechar com a tecla "ESC"
        });
        $('#modalUtilizadores').on('shown.bs.modal', function () {
            $('#nome').trigger('focus');
            let form = $(this).find('form')[0];
            $('#senhas').show();
            form.reset();
            $('.section-title').text('Cadastrar Usuários');
            // Remove mensagens de erro e estilos de validação
            $(form).find('.form-control').removeClass('is-invalid'); // Remove os estilos de erro
            $(form).find('.invalid-feedback').remove(); // Remove as mensagens de erro (caso haja)
            $("#formUtilizadores").validate({
                rules: {
                    idNivel: {
                        required: true // Campo obrigatório
                    },
                    unome: {
                        required: true,
                        minlength: 3
                    },
                    usuario: {
                        required: true,
                        minlength: 3
                    },
                    email: {
                        required: false, // O campo não é obrigatório
                        email: true     // Valida se é um e-mail no formato correto
                    },
                    password: {
                        required: true,
                        minlength: 6 // Exemplo: mínimo de 6 caracteres
                    },
                    password1: {
                        required: true,
                        equalTo: "#password" // Valida se é igual ao campo de senha1
                    }
                },
                messages: {
                    idNivel: {
                        required: "Por favor, selecione uma opção." // Mensagem de erro
                    },
                    unome: {
                        required: "Digite o primeiro e o último nome",
                        minlength: "O nome deve ter pelo menos 3 caracteres."
                    },
                    usuario: {
                        required: "Digite o nome de acesso",
                        minlength: "O nome deve ter pelo menos 3 caracteres."
                    },
                    password: {
                        required: "Por favor, insira sua senha.",
                        minlength: "A senha deve ter pelo menos 6 caracteres."
                    },
                    password1: {
                        required: "Por favor, confirme sua senha.",
                        equalTo: "As senhas não correspondem."
                    }
                },
                errorElement: 'div',
                errorClass: 'invalid-feedback',
                highlight: function (element) {
                    $(element).addClass('is-invalid'); // Adiciona classe de erro Bootstrap ao campo
                },
                unhighlight: function (element) {
                    $(element).removeClass('is-invalid'); // Remove a classe de erro quando válido
                },
                errorPlacement: function (error, element) {
                    error.insertAfter(element); // Insere a mensagem de erro logo após o campo
                },

                success: function (label, element) {
                    // Remove o tooltip quando o campo for válido
                    $(element).next('.error-tooltip').remove();
                },
                submitHandler: function (form) {
                    // Chama a função submeteFormLogin quando o formulário for validado com sucesso
                    submeteFormLogin();

                }
            });
        });
    });
    $(document).on('click', '.fechaModalEntidade', function () {
        $("#modalUtilizadores").modal('hide');
    });
    $(document).on('click', '.fechamodalPermissoes', function () {
        $("#modalPermissoes").modal('hide');
    });
    $(document).on('click', '.fechaModalPassWord', function () {
        $("#modalAlteraPassWord").modal('hide');
    });


    function submeteFormLogin() {
        var data = $("#formUtilizadores").serialize(); // a function serialize serve para pegar todos os valores que foram colocados nos inputs do form
        // Concatena a variável extra aos dados do formulário
        var parametrosAdicionais = {
            idCaixaLoja: idCaixaLoja,
        };
        data += "&" + $.param(parametrosAdicionais);
        $.ajax({
            // está é a função ajax, do jquery, ela será usada para fazer a requisição assícrona.
            url: BASE_URL + "CUtilizador/regitarUtilizadores", // aqui vai a url da requisição
            data: data, // aqui vai os dados para o servidor, geralmente são os inputs do form
            method: "POST", // aqui vai o método da requisição, acho que você já sabe sobre o get e post !
            dataType: "json", // aqui será o tipo de resposta que vamos receber, será no formato json, um formato simples e mais usado.
            success: function (data) {
                // Admin/dashboard?page=dashboard
                if (data === 'OK') {
                    $("#modalUtilizadores").modal('hide');
                    $('#tabelaUtilizadores').DataTable().ajax.reload();
                } else {
                    Swal.fire({
                        icon: 'info', // Tipo do alerta
                        title: 'Informação!',
                        text: data // Mensagem de erro
                    });
                }
            },
            error: function () {
                // Caso ocorra um erro na requisição
                Swal.fire({
                    icon: 'warning', // Tipo do alerta: aviso
                    title: 'Atenção!',
                    text: 'Ocorreu um erro na comunicação com o servidor.'
                });
            }
        });
    }


    // Evento de clique para o botão de editar
    $('#tabelaUtilizadores tbody').on('click', '.editar', function () {
        var idUsuario = $(this).data('id');

        $("#modalUtilizadores").modal({
            backdrop: 'static', // Impede fechar ao clicar fora
            keyboard: false     // Impede fechar com a tecla "ESC"
        });
        $('#modalUtilizadores').on('shown.bs.modal', function () {
            $('#nome').trigger('focus');
            $('#senhas').hide();
            let form = $(this).find('form')[0];
            $('.section-title').text('Editar Usuários');
            pegaDadosUtilizadorEditar(idUsuario);
            // Remove mensagens de erro e estilos de validação
            $(form).find('.form-control').removeClass('is-invalid'); // Remove os estilos de erro
            $(form).find('.invalid-feedback').remove(); // Remove as mensagens de erro (caso haja)
            $("#formUtilizadores").validate({

                rules: {
                    idNivel: {
                        required: true // Campo obrigatório
                    },
                    unome: {
                        required: true,
                        minlength: 3
                    },
                    usuario: {
                        required: true,
                        minlength: 3
                    },
                    email: {
                        required: false, // O campo não é obrigatório
                        email: true     // Valida se é um e-mail no formato correto
                    }

                },
                messages: {
                    idNivel: {
                        required: "Por favor, selecione uma opção." // Mensagem de erro
                    },
                    unome: {
                        required: "Digite o primeiro e o último nome",
                        minlength: "O nome deve ter pelo menos 3 caracteres."
                    },
                    usuario: {
                        required: "Digite o nome de acesso",
                        minlength: "O nome deve ter pelo menos 3 caracteres."
                    }

                },

                errorElement: 'div',
                errorClass: 'invalid-feedback',
                highlight: function (element) {
                    $(element).addClass('is-invalid'); // Adiciona classe de erro Bootstrap ao campo
                },
                unhighlight: function (element) {
                    $(element).removeClass('is-invalid'); // Remove a classe de erro quando válido
                },
                errorPlacement: function (error, element) {
                    error.insertAfter(element); // Insere a mensagem de erro logo após o campo
                },

                success: function (label, element) {
                    // Remove o tooltip quando o campo for válido
                    $(element).next('.error-tooltip').remove();
                },
                submitHandler: function (form) {
                    // Chama a função submeteFormLogin quando o formulário for validado com sucesso
                    submeteEditUsuario(idUsuario);

                }
            });
        });

    });
    function submeteEditUsuario(idUsuario) {
        var data = $("#formUtilizadores").serialize(); // a function serialize serve para pegar todos os valores que foram colocados nos inputs do form
        // Concatena a variável extra aos dados do formulário
        var parametrosAdicionais = {
            idUsuario: idUsuario
        };
        data += "&" + $.param(parametrosAdicionais);
        $.ajax({
            // está é a função ajax, do jquery, ela será usada para fazer a requisição assícrona.
            url: BASE_URL + "CUtilizador/atualizar_usuario", // aqui vai a url da requisição
            data: data, // aqui vai os dados para o servidor, geralmente são os inputs do form
            method: "POST", // aqui vai o método da requisição, acho que você já sabe sobre o get e post !
            dataType: "json", // aqui será o tipo de resposta que vamos receber, será no formato json, um formato simples e mais usado.
            success: function (data) {
                // Admin/dashboard?page=dashboard
                if (data === 'OK') {
                    $("#modalUtilizadores").modal('hide');
                    $('#tabelaUtilizadores').DataTable().ajax.reload();
                } else {
                    Swal.fire({
                        icon: 'info', // Tipo do alerta
                        title: 'Informação!',
                        text: data // Mensagem de erro
                    });
                }
            },
            error: function () {
                // Caso ocorra um erro na requisição
                Swal.fire({
                    icon: 'warning', // Tipo do alerta: aviso
                    title: 'Atenção!',
                    text: 'Ocorreu um erro na comunicação com o servidor.'
                });
            }
        });
    }

    // Evento de clique para o botão de eliminar
    $('#tabelaUtilizadores tbody').on('click', '.eliminar', function () {
        var idUtilizador = $(this).data('id');
        Swal.fire({
            icon: 'question', // Tipo do alerta: pergunta
            // title: 'Atenção!',
            text: 'Deseja remover  o utilizador selecionado',
            showCancelButton: true, // Mostra o botão de "Não"
            confirmButtonText: 'Sim', // Texto do botão de "Sim"
            cancelButtonText: 'Não', // Texto do botão de "Não"
            confirmButtonColor: '#3085d6', // Cor do botão de "Sim"
            cancelButtonColor: '#d33'      // Cor do botão de "Não"
        }).then((result) => {
            if (result.isConfirmed) {
                $.ajax({
                    type: 'post',
                    url: BASE_URL + "CUtilizador/eliminarUtilizador",
                    data: {idUtilizador: idUtilizador
                    },
                    dataType: 'json',
                    success: function (dados) {
                        if (dados === 'OK') {
                            $('#tabelaUtilizadores').DataTable().ajax.reload();
                        }
                        if (dados === 'N') {
                            Swal.fire({
                                icon: 'warning', // Tipo do alerta: aviso
                                title: 'Atenção!',
                                text: 'O utilizador selecionado   não pode ser removido por possuir documentos associados a ele.'
                            });
                        }
                    }
                });
            } else if (result.dismiss === Swal.DismissReason.cancel) {
                // Ação para quando o usuário clica em "Não"
                console.log('Usuário clicou em Não');
            }
        });
    });
    pegaNiveisAcesso();
    function pegaNiveisAcesso() {
        $.ajax({
            url: BASE_URL + "CUtilizador/clistar_niveis_acesso", // URL da requisição
            type: 'post',
            dataType: 'json',
            success: function (dados) {
                var option = '<option value="">Selecione o nive de permissão para o utilizador</option>'; // Opção padrão "Selecione"
                if (dados.length > 0) {
                    $.each(dados, function (i, obj) {
                        option += '<option value="' + obj.idNivel + '">' + obj.nivel + '</option>';
                    });
                } else {
                    // Caso o retorno esteja vazio, mostra uma mensagem padrão
                    option = '<option value="" disabled selected>Nenhum nivel selecionado  </option>';
                }
                $('#idSelectNiveis').html(option).show();
            },
            error: function () {
                // Em caso de erro na requisição AJAX
                var option = '<option value="" disabled selected>Erro ao carregar os niveis de acesso</option>';
                $('#idSelectNiveis').html(option).show();
            }
        });
    }
    // Para preencher o Select2 com um valor específico
    function preencheNivelSelecionado(nivelUtilzador, idNivel) {
        // Criar uma nova opção e selecioná-la
        var novaOpcao = new Option(nivelUtilzador, idNivel, true, true);
        $('#idSelectNiveis').append(novaOpcao).trigger('change');
    }
    function pegaDadosUtilizadorEditar(idUsuario) {

        // Realizar a requisição AJAX para obter os dados dos produtos
        $.ajax({
            type: 'get',
            url: BASE_URL + "CUtilizador/pegadados_utilizador_editar", // Substitua pela URL do seu endpoint
            dataType: 'json',
            data: {
                idUsuario: idUsuario
            },
            success: function (dados, armazens) {
                preencheNivelSelecionado(dados.nivelUtilzador, dados.idNivel); // Preenche o nível de acesso no Select2
                console.log(dados.unome);
                $('#unome').val(dados.unome);
                $('#usuario').val(dados.nome);
                // Define o estado do switch com base no valor de desconto
                if (dados.desconto === 's') {
                    $('#switchS').prop('checked', true); // Ativa o switch
                } else {
                    $('#switchS').prop('checked', false); // Desativa o switch
                }
//              // Checa os checkboxes dos armazéns com base nos valores retornados
                if (dados.armazens && Array.isArray(dados.armazens)) {
                    dados.armazens.forEach(function (armazem) {
                        var checkbox = $('#checkbox_' + armazem.id); // Seleciona o checkbox pelo ID
                        if (armazem.checked === 's') {
                            checkbox.prop('checked', true); // Marca como checado
                        } else {
                            checkbox.prop('checked', false); // Desmarca
                        }
                    });
                }
            },
            error: function (xhr, status, error) {
                console.error("Erro ao obter os produtos:", error);
                // Trate o erro como necessário
            }

        });
    }
    $('#tabelaUtilizadores tbody').on('click', '.permissoes', function () {
        var idUsuario = $(this).data('id');
        var nomeUsuario = $(this).closest('tr').find('td:nth-child(1)').text().trim(); // Obtém o nome da segunda célula
        // Altera dinamicamente o título da seção
        $('.section-title').text(`Permissões para: ${nomeUsuario}`);
        carregarPermissoes(idUsuario);
        $('#modalPermissoes').modal('show'); // Use o método do Bootstrap
    });
    function carregarPermissoes(idUsuario) {
        $.ajax({
            url: BASE_URL + "CUtilizador/permissoesUsuarios",
            type: "GET",
            dataType: "json",
            data: {idUsuario: idUsuario},
            success: function (dados) {
                // Limpa a área onde as checkboxes serão adicionadas
                $("#permissoesContainer").empty();

                // Itera sobre os dados retornados e cria as checkboxes dinamicamente
                dados.forEach(function (item) {
                    let isChecked = item.status === 's' ? "checked" : "";
                    let checkboxHtml = `
                    <div class="custom-control custom-checkbox mb-4">
                        <input type="checkbox" class="custom-control-input" id="checkbox_${item.idPermissao}" ${isChecked} data-id="${item.idPermissao}">
                        <label class="custom-control-label" for="checkbox_${item.idPermissao}">${item.per}</label>
                    </div>
                `;
                    $("#permissoesContainer").append(checkboxHtml);
                    /// Recalcular os estilos dos componentes customizados após a adição
                    $('.custom-control-input').each(function () {
                        $(this).parent().removeClass('custom-control').addClass('custom-control');
                        $(this).next('label').removeClass('custom-control-label').addClass('custom-control-label');
                    });

                    // Forçar a reativação do estilo de checkbox
                    $(".custom-control-input").trigger("change");
                });
            },
            error: function (xhr, status, error) {
                console.error("Erro ao carregar permissões:", error);
            }
        });
    }
    $('#tabelaUtilizadores tbody').on('click', '.trocaSenha', function () {
        var idUsuario = $(this).data('id');
        var nomeUsuario = $(this).closest('tr').find('td:nth-child(1)').text().trim(); // Obtém o nome da segunda célula
        let form = $("#formPassWord");

        $('#passwordNova').val('');
        $('.section-title').text(`Trocar senha para: ${nomeUsuario}`);
        $("#modalAlteraPassWord").modal({
            backdrop: 'static', // Impede fechar ao clicar fora
            keyboard: false     // Impede fechar com a tecla "ESC"
        });
        $('#modalAlteraPassWord').on('shown.bs.modal', function () {
            $('#passwordNova').trigger('focus');

            let form = $(this).find('form')[0];
            // Remove mensagens de erro e estilos de validação
            $(form).find('.form-control').removeClass('is-invalid'); // Remove os estilos de erro
            $(form).find('.invalid-feedback').remove(); // Remove as mensagens de erro (caso haja)
            $("#formPassWord").validate({

                rules: {
                    password: {
                        required: true,
                        minlength: 6 // Exemplo: mínimo de 6 caracteres
                    }
                },
                messages: {
                    password: {
                        required: "Por favor, insira a nova senha.",
                        minlength: "A senha deve ter pelo menos 6 caracteres."
                    }
                },

                errorElement: 'div',
                errorClass: 'invalid-feedback',
                highlight: function (element) {
                    $(element).addClass('is-invalid'); // Adiciona classe de erro Bootstrap ao campo
                },
                unhighlight: function (element) {
                    $(element).removeClass('is-invalid'); // Remove a classe de erro quando válido
                },
                errorPlacement: function (error, element) {
                    error.insertAfter(element); // Insere a mensagem de erro logo após o campo
                },

                success: function (label, element) {
                    // Remove o tooltip quando o campo for válido
                    $(element).next('.error-tooltip').remove();
                },
                submitHandler: function (form) {
                    // Chama a função submeteFormLogin quando o formulário for validado com sucesso
                    submeteFormPassWord(idUsuario);

                }
            });
        });
    });
    function submeteFormPassWord(idUsuario) {
        var data = $("#formPassWord").serialize(); // a function serialize serve para pegar todos os valores que foram colocados nos inputs do form
        // Concatena a variável extra aos dados do formulário
        var parametrosAdicionais = {
            idUsuario: idUsuario
        };
        data += "&" + $.param(parametrosAdicionais);
        $.ajax({
            // está é a função ajax, do jquery, ela será usada para fazer a requisição assícrona.
            url: BASE_URL + "CUtilizador/atualizar_senha", // aqui vai a url da requisição
            data: data, // aqui vai os dados para o servidor, geralmente são os inputs do form
            method: "POST", // aqui vai o método da requisição, acho que você já sabe sobre o get e post !
            dataType: "json", // aqui será o tipo de resposta que vamos receber, será no formato json, um formato simples e mais usado.
            success: function (data) {
                // Admin/dashboard?page=dashboard
                if (data === 'OK') {
                    $("#modalAlteraPassWord").modal('hide');
                    Swal.fire({
                        icon: 'info', // Tipo do alerta
                        title: 'Informação!',
                        text: 'Password alterada' // Mensagem inf
                    });
                } else {
                    Swal.fire({
                        icon: 'warning', // Tipo do alerta
                        title: 'Informação!',
                        text: data // Mensagem de erro
                    });
                }
            },
            error: function () {
                // Caso ocorra um erro na requisição
                Swal.fire({
                    icon: 'warning', // Tipo do alerta: aviso
                    title: 'Atenção!',
                    text: 'Ocorreu um erro na comunicação com o servidor.'
                });
            }
        });
    }
});





